# SPDX-FileCopyrightText: 2025 Julius Deynet <julius.deynet@stud-mail.uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

annotated_peaks = as.data.frame(read.delim("./resources/annotated_peaks_hg38_right.tsv"))
lfc_data = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")

ebox_motifs <- c("CACGTG", "CACGCG", "CATGCG", "CATGTG", "CACGAG", "CACATG")

merged = merge(lfc_data, annotated_peaks, by="gene_id")
merged = merged %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

peaks_with_canonical = merged[is.na(merged$sum_eboxes) | merged$sum_eboxes == merged$CACGTG, ]

correlation = cor(peaks_with_canonical$CACGTG, peaks_with_canonical$coverage_myc, method = "spearman", use = "pairwise.complete.obs")

levels = sort(unique(peaks_with_canonical$CACGTG))

peaks_with_canonical$CACGTG = factor(peaks_with_canonical$CACGTG, levels = levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- peaks_with_canonical %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(peaks_with_canonical, aes(x = CACGTG, y = coverage_myc)) +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG == 0, ],outliers = FALSE) +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG != 0, ], outliers = FALSE, aes(color = "CACGTG")) +
  scale_color_manual(values = c("CACGTG" = scales::hue_pal()(length(ebox_motifs))[1]), guide = "none") +
  labs(title = "Coverage_MYC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -10, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = 270) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 320, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_coverage_cacgtg_with_coloring.svg", plot, width = 9, height = 6)


peaks_with_canonical = merged[is.na(merged$sum_eboxes) | merged$sum_eboxes_and_CANNTG_total == merged$CACGTG, ]

correlation = cor(peaks_with_canonical$CACGTG, peaks_with_canonical$coverage_myc, method = "spearman", use = "pairwise.complete.obs")

levels = sort(unique(peaks_with_canonical$CACGTG))

peaks_with_canonical$CACGTG = factor(peaks_with_canonical$CACGTG, levels = levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- peaks_with_canonical %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(peaks_with_canonical, aes(x = CACGTG, y = coverage_myc)) +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG == 0, ],outliers = FALSE) +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG != 0, ], outliers = FALSE, aes(color = "CACGTG")) +
  scale_color_manual(values = c("CACGTG" = scales::hue_pal()(length(ebox_motifs))[1]), guide = "none") +
  labs(title = "Coverage_MYC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -10, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = 270) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 320, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_coverage_cacgtg_with_coloring_CANNTG.svg", plot, width = 9, height = 6)


merged = merge(lfc_data, annotated_peaks, by="gene_id", all.x = TRUE)
merged = merged %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

peaks_with_canonical = merged[is.na(merged$sum_eboxes) | merged$sum_eboxes == merged$CACGTG, ]

correlation = cor(peaks_with_canonical$CACGTG, peaks_with_canonical$log2FoldChange, method = "spearman", use = "pairwise.complete.obs")

levels = sort(unique(peaks_with_canonical$CACGTG))

peaks_with_canonical$CACGTG = ifelse(is.na(peaks_with_canonical$CACGTG), "No Assigned Peak", peaks_with_canonical$CACGTG)

levels = c("No Assigned Peak", levels)

peaks_with_canonical$CACGTG = factor(peaks_with_canonical$CACGTG, levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- peaks_with_canonical %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(peaks_with_canonical, aes(x = CACGTG, y = log2FoldChange)) +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG == "No Assigned Peak", ],outliers = FALSE, color="grey") +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG == 0, ],outliers = FALSE) +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG != 0 & peaks_with_canonical$CACGTG != "No Assigned Peak", ], outliers = FALSE, aes(color = "CACGTG")) +
  scale_color_manual(values = c("CACGTG" = scales::hue_pal()(length(ebox_motifs))[1]), guide = "none") +
  labs(title = "LFC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "-log2(Fold Change MYC vs. MYC Depletion)") +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -2, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = 2.2) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 3, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_lfc_cacgtg_with_colors.svg", plot, width = 9, height = 6)


peaks_with_canonical = merged[is.na(merged$sum_eboxes_and_CANNTG_total) | merged$sum_eboxes_and_CANNTG_total == merged$CACGTG, ]

correlation = cor(peaks_with_canonical$sum_eboxes_and_CANNTG_total, peaks_with_canonical$log2FoldChange, method = "spearman", use = "pairwise.complete.obs")

levels = sort(unique(peaks_with_canonical$CACGTG))

peaks_with_canonical$CACGTG = ifelse(is.na(peaks_with_canonical$CACGTG), "No Assigned Peak", peaks_with_canonical$CACGTG)

levels = c("No Assigned Peak", levels)

peaks_with_canonical$CACGTG = factor(peaks_with_canonical$CACGTG, levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- peaks_with_canonical %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(peaks_with_canonical, aes(x = CACGTG, y = log2FoldChange)) +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG == "No Assigned Peak", ],outliers = FALSE, color="grey") +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG == 0, ],outliers = FALSE) +
  geom_boxplot(data = peaks_with_canonical[peaks_with_canonical$CACGTG != 0 & peaks_with_canonical$CACGTG != "No Assigned Peak", ], outliers = FALSE, aes(color = "CACGTG")) +
  scale_color_manual(values = c("CACGTG" = scales::hue_pal()(length(ebox_motifs))[1]), guide = "none") +
  labs(title = "LFC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "-log2(Fold Change MYC vs. MYC Depletion)") +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -2, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = 2) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 3, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_lfc_cacgtg_with_colors_vs_CANNTG.svg", plot, width = 9, height = 6)


merged = merge(lfc_data, annotated_peaks, by="gene_id")
merged = merged %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

peaks_without_canonical = merged[merged$CACGTG == 0, ]

correlation = cor(peaks_without_canonical$sum_eboxes, peaks_without_canonical$coverage_myc, method = "spearman", use = "pairwise.complete.obs")

levels = sort(unique(peaks_without_canonical$sum_eboxes))

peaks_without_canonical$sum_eboxes = factor(peaks_without_canonical$sum_eboxes, levels = levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- peaks_without_canonical %>%
  group_by(sum_eboxes) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(peaks_without_canonical, aes(x = sum_eboxes, y = coverage_myc)) +
  geom_boxplot(outliers = FALSE) +
  labs(title = "Coverage_MYC Across Peaks without CACGTG E-box Motif",
       x = "Sum of non-Canonical E-box",
       y = "Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = sum_eboxes, y = -10, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = 180) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 220, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_coverage_non_cacgtg.svg", plot, width = 9, height = 6)

peaks_without_canonical = merged[merged$CACGTG == 0, ]

correlation = cor(peaks_without_canonical$sum_eboxes_and_CANNTG_total, peaks_without_canonical$coverage_myc, method = "spearman", use = "pairwise.complete.obs")

levels = sort(unique(peaks_without_canonical$sum_eboxes_and_CANNTG_total))

peaks_without_canonical$sum_eboxes_and_CANNTG_total = factor(peaks_without_canonical$sum_eboxes_and_CANNTG_total, levels = levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- peaks_without_canonical %>%
  group_by(sum_eboxes_and_CANNTG_total) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(peaks_without_canonical, aes(x = sum_eboxes_and_CANNTG_total, y = coverage_myc)) +
  geom_boxplot(outliers = FALSE) +
  labs(title = "Coverage_MYC Across Peaks without CACGTG E-box Motif",
       x = "Sum of non-Canonical E-box",
       y = "Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = sum_eboxes_and_CANNTG_total, y = -10, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = 120) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 160, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_coverage_non_cacgtg_CANNTG.svg", plot, width = 9, height = 6)


merged = merge(lfc_data, annotated_peaks, by="gene_id", all.x = TRUE)
merged = merged %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

peaks_without_canonical = merged[is.na(merged$CACGTG) | merged$CACGTG == 0, ]

correlation = cor(peaks_without_canonical$sum_eboxes, peaks_without_canonical$log2FoldChange, method = "spearman", use = "pairwise.complete.obs")

levels = sort(unique(peaks_without_canonical$sum_eboxes))

peaks_without_canonical$sum_eboxes = ifelse(is.na(peaks_without_canonical$sum_eboxes), "No Assigned Peak", peaks_without_canonical$sum_eboxes)

levels = c("No Assigned Peak", levels)

peaks_without_canonical$sum_eboxes = factor(peaks_without_canonical$sum_eboxes, levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- peaks_without_canonical %>%
  group_by(sum_eboxes) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(peaks_without_canonical, aes(x = sum_eboxes, y = log2FoldChange)) +
  geom_boxplot(outliers = FALSE) +
  labs(title = "LFC Across Peaks without CACGTG E-box Motif",
       x = "Sum of non-Canonical E-box",
       y = "-log2(Fold Change MYC vs. MYC Depletion)") +
  geom_text(
    data = counts,
    aes(x = sum_eboxes, y = -2, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = 2) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 3, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_lfc_non_cacgtg.svg", plot, width = 9, height = 6)

merged = merge(lfc_data, annotated_peaks, by="gene_id", all.x = TRUE)
merged = merged %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

peaks_without_canonical = merged[is.na(merged$CACGTG) | merged$CACGTG == 0, ]

correlation = cor(peaks_without_canonical$sum_eboxes_and_CANNTG_total, peaks_without_canonical$log2FoldChange, method = "spearman", use = "pairwise.complete.obs")

levels = sort(unique(peaks_without_canonical$sum_eboxes_and_CANNTG_total))

peaks_without_canonical$sum_eboxes_and_CANNTG_total = ifelse(is.na(peaks_without_canonical$sum_eboxes_and_CANNTG_total), "No Assigned Peak", peaks_without_canonical$sum_eboxes_and_CANNTG_total)

levels = c("No Assigned Peak", levels)

peaks_without_canonical$sum_eboxes_and_CANNTG_total = factor(peaks_without_canonical$sum_eboxes_and_CANNTG_total, levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- peaks_without_canonical %>%
  group_by(sum_eboxes_and_CANNTG_total) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(peaks_without_canonical, aes(x = sum_eboxes_and_CANNTG_total, y = log2FoldChange)) +
  geom_boxplot(outliers = FALSE) +
  labs(title = "LFC Across Peaks without CACGTG E-box Motif",
       x = "Sum of non-Canonical E-box",
       y = "-log2(Fold Change MYC vs. MYC Depletion)") +
  geom_text(
    data = counts,
    aes(x = sum_eboxes_and_CANNTG_total, y = -2, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = 2) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 3, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_lfc_non_cacgtg_CANNTG.svg", plot, width = 9, height = 6)



subset = annotated_peaks[annotated_peaks$CACGTG <= 3, ]

subset$category = ifelse(subset$CACGTG == subset$sum_eboxes, "CACGTG only", "Other Motifs")

subset$category = factor(subset$category, levels = c("CACGTG only", "Other Motifs"))

levels = sort(unique(subset$CACGTG))

subset$CACGTG = factor(subset$CACGTG, levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- subset %>%
  group_by(CACGTG, category) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

correlation = cor(as.numeric(subset$CACGTG), subset$coverage_myc, method = "spearman", use = "pairwise.complete.obs")

plot = ggplot(subset, aes(x = CACGTG, y = coverage_myc)) +
  geom_boxplot(outliers = FALSE, aes(color = category)) +
  labs(title = "Coverage_MYC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "Coverage_MYC") +
  scale_color_manual(values = RColorBrewer::brewer.pal(2, "Dark2")) +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -20, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test",
                     aes(x = CACGTG, y = coverage_myc, group = category),
                     label = "p.signif", hide.ns = FALSE, label.y = 150) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 160, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_coverage_cacgtg_vs_other_motifs.svg", plot, width = 9, height = 6)



subset = annotated_peaks[annotated_peaks$CACGTG <= 3, ]

subset = merge(subset, lfc_data, by="gene_id")
subset = subset %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

subset$category = ifelse(subset$CACGTG == subset$sum_eboxes, "CACGTG only", "Other Motifs")

subset$category = factor(subset$category, levels = c("CACGTG only", "Other Motifs"))

levels = sort(unique(subset$CACGTG))

subset$CACGTG = factor(subset$CACGTG, levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- subset %>%
  group_by(CACGTG, category) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

correlation = cor(as.numeric(subset$CACGTG), subset$coverage_myc, method = "spearman", use = "pairwise.complete.obs")

plot = ggplot(subset, aes(x = CACGTG, y = coverage_myc)) +
  geom_boxplot(outliers = FALSE, aes(color = category)) +
  labs(title = "Coverage_MYC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "Coverage_MYC") +
  scale_color_manual(values = RColorBrewer::brewer.pal(2, "Dark2")) +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -20, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test",
                     aes(x = CACGTG, y = coverage_myc, group = category),
                     label = "p.signif", hide.ns = FALSE, label.y = 200) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 220, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_coverage_cacgtg_vs_other_motifs_strongest.svg", plot, width = 9, height = 6)


subset = annotated_peaks[annotated_peaks$CACGTG <= 3, ]

subset$category = ifelse(subset$CACGTG == subset$sum_eboxes_and_CANNTG_total, "CACGTG only", ifelse(subset$CACGTG < subset$sum_eboxes, "Other Main Motifs","Other Motifs"))

subset$category = factor(subset$category, levels = c("CACGTG only", "Other Main Motifs","Other Motifs"))

levels = sort(unique(subset$CACGTG))

subset$CACGTG = factor(subset$CACGTG, levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- subset %>%
  group_by(CACGTG, category) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

correlation = cor(as.numeric(subset$CACGTG), subset$coverage_myc, method = "spearman", use = "pairwise.complete.obs")

plot = ggplot(subset, aes(x = CACGTG, y = coverage_myc)) +
  geom_boxplot(outliers = FALSE, aes(color = category)) +
  labs(title = "Coverage_MYC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "Coverage_MYC") +
  scale_color_manual(values = RColorBrewer::brewer.pal(3, "Dark2")) +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -20, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test",
                     aes(x = CACGTG, y = coverage_myc, group = category),
                     label = "p.signif", hide.ns = FALSE, label.y = 150) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 160, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_coverage_cacgtg_vs_other_motifs_CANNTG.svg", plot, width = 9, height = 6)


subset = annotated_peaks

subset = merge(subset, lfc_data, by="gene_id")
subset = subset %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

subset2 = subset[subset$CACGTG < subset$sum_eboxes_and_CANNTG_total, ]
subset2$category = "Other CANNTG Motifs"

subset$category = ifelse(subset$CACGTG == subset$sum_eboxes_and_CANNTG_total, "CACGTG only", ifelse(subset$CACGTG < subset$sum_eboxes, "Other Main Motifs","Other Motifs"))

subset = subset(subset, category != "Other Motifs")

# combine rows of subset and subset2
subset = rbind(subset, subset2)

subset$category = factor(subset$category, levels = c("CACGTG only", "Other Main Motifs","Other CANNTG Motifs"))

levels = c("0", "1", "2+")

subset$CACGTG = factor(ifelse(subset$CACGTG >= 2, "2+", subset$CACGTG), levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- subset %>%
  group_by(CACGTG, category) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

correlation = cor(as.numeric(subset$CACGTG), subset$coverage_myc, method = "spearman", use = "pairwise.complete.obs")

plot = ggplot(subset, aes(x = CACGTG, y = coverage_myc)) +
  geom_point(aes(color = category), position = position_jitterdodge(jitter.width =  0.4, jitter.height = 0), alpha = 0.1) +
  geom_boxplot(outliers = FALSE, aes(color = category)) +
  labs(#title = "Coverage_MYC Across Strongest Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "MYC Coverage",
       color = "Motif Composition") +
  scale_color_manual(values = RColorBrewer::brewer.pal(3, "Dark2")) +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -20, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test",
                     aes(x = CACGTG, y = coverage_myc, group = category),
                     label = "p.signif", hide.ns = FALSE, label.y = 200) +
  theme_minimal() +
  guides(color = "none") +
  coord_cartesian(ylim = c(-20, 210)) +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),)
plot
ggsave("./box_coverage_cacgtg_vs_other_motifs_strongest_CANNTG.pdf", plot, width = 9, height = 6)



subset = annotated_peaks[annotated_peaks$CACGTG <= 3, ]

subset = merge(subset, lfc_data, by="gene_id", all.y = TRUE)
subset = subset %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

subset$category = ifelse(subset$CACGTG == subset$sum_eboxes, "CACGTG only", "Other Motifs")

subset$category = factor(subset$category, levels = c("CACGTG only", "Other Motifs"))

levels = sort(unique(subset$CACGTG))

subset$CACGTG = ifelse(is.na(subset$CACGTG), "No Assigned Peak", subset$CACGTG)

levels = c("No Assigned Peak", levels)

subset$CACGTG = factor(subset$CACGTG, levels =  levels)

sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- subset %>%
  group_by(CACGTG, category) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

correlation = cor(as.numeric(subset$CACGTG), subset$log2FoldChange, method = "spearman", use = "pairwise.complete.obs")

plot = ggplot(subset, aes(x = CACGTG, y = log2FoldChange)) +
  geom_boxplot(data=subset[subset$CACGTG == "No Assigned Peak" ,], outliers = FALSE, color = "grey") +
  geom_boxplot(data=subset[subset$CACGTG != "No Assigned Peak" ,], outliers = FALSE, aes(color = category)) +
  labs(title = "LFC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "-log2(Fold Change MYC vs. MYC Depletion)") +
  scale_color_manual(values = RColorBrewer::brewer.pal(3, "Dark2")) +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -2, label = n), # Fixed y position
    size = 4
  )+
  stat_compare_means(method="wilcox.test",
                     aes(x = CACGTG, y = log2FoldChange, group = category),
                     label = "p.signif", hide.ns = FALSE, label.y = 3) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  annotate("text", x = 1, y = 3.5, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 0, size = 5, color = "blue")
plot
ggsave("./box_lfc_cacgtg_vs_other_motifs.svg", plot, width = 9, height = 6)


subset = annotated_peaks

subset = merge(subset, lfc_data, by="gene_id", all.y = TRUE)
subset = subset %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

subset2 = subset[subset$CACGTG < subset$sum_eboxes_and_CANNTG_total, ]
subset2$category = "Other CANNTG Motifs"
subset2 = subset(subset2, !is.na(CACGTG))

subset$category = ifelse(subset$CACGTG == subset$sum_eboxes_and_CANNTG_total, "CACGTG only", ifelse(subset$CACGTG < subset$sum_eboxes, "Other Main Motifs","Other Motifs"))

subset = subset(subset, is.na(CACGTG) | category != "Other Motifs")

# combine rows of subset and subset2
subset = rbind(subset, subset2)

subset$category = factor(subset$category, levels = c("CACGTG only", "Other Main Motifs","Other CANNTG Motifs"))


levels = c("0", "1", "2+", "No Assigned Peak")

subset$CACGTG = factor(ifelse(is.na(subset$CACGTG), "No Assigned Peak", ifelse(subset$CACGTG >= 2, "2+", subset$CACGTG)), levels =  levels)


sequential_comparisons <- list()

for (i in 1:(length(levels) - 1)) {
  sequential_comparisons[[i]] <- c(as.character(levels[i]), as.character(levels[i + 1]))
}

counts <- subset %>%
  group_by(CACGTG, category) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(CACGTG) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

plot = ggplot(subset, aes(x = CACGTG, y = log2FoldChange)) +
  geom_boxplot(data=subset[subset$CACGTG == "No Assigned Peak" ,], outliers = FALSE, color = "grey") +
  geom_point(data = subset[subset$CACGTG != "No Assigned Peak" ,], aes(color = category), position = position_jitterdodge(jitter.width =  0.4, jitter.height = 0), alpha = 0.1) +
  geom_boxplot(data=subset[subset$CACGTG != "No Assigned Peak" ,], outliers = FALSE, aes(color = category)) +
  labs(#title = "LFC Across Peaks with CACGTG E-box Motif",
       x = "CACGTG E-boxes",
       y = "-log2(Fold Change MYC vs. MYC Depletion)",
       color = "Motif Composition") +
  scale_color_manual(values = RColorBrewer::brewer.pal(3, "Dark2")) +
  geom_text(
    data = counts,
    aes(x = CACGTG, y = -1.5, label = n), # Fixed y position
    size = 4
  ) +
  stat_compare_means(data = subset[subset$category != "CACGTG only",],  method="wilcox.test",
                     aes(x = CACGTG, y = log2FoldChange, group = category),
                     label = "p.signif", hide.ns = FALSE, label.y = 3) +
  theme_minimal() +
  coord_cartesian(ylim = c(-1.5, 3)) +
  guides(color = "none") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),)
plot
ggsave("./box_lfc_cacgtg_vs_other_motifs_CANNTG.pdf", plot, width = 9, height = 6)
