# SPDX-FileCopyrightText: 2025 Julius Deynet <julius.deynet@stud-mail.uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

ebox_motifs <- c("CACGTG", "CACGCG", "CATGCG", "CATGTG", "CACGAG", "CACATG")

ebox_inside_cpg_names = paste0(ebox_motifs, "_inside_cpg")

group_by_motif = annotated_peaks



group_by_motif$motif = ebox_motifs[apply(group_by_motif[, ebox_motifs], 1, which.max)]
group_by_motif$motif = ifelse(group_by_motif$sum_eboxes > 1, "2+ E-boxes", ifelse(group_by_motif$sum_eboxes == 0, "No E-box", group_by_motif$motif))

group_by_motif$motif = factor(group_by_motif$motif, levels = c("No E-box", ebox_motifs, "2+ E-boxes"))

combined = group_by_motif

combined = combined %>% mutate(inside_cpg = case_when(
  sum_eboxes == 1 & sum_eboxes_inside_cpg == 1 ~ TRUE,
  sum_eboxes == 1 & sum_eboxes_inside_cpg == 0 ~ FALSE,
  TRUE ~ NA
))

counts <- combined  %>%
  group_by(motif, inside_cpg) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(motif) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

combined$group_inside_cpg <- interaction(combined$motif, combined$inside_cpg)

library(colorspace)

# Define original ggplot2 colors
ggplot_colors <- scales::hue_pal()(length(ebox_motifs))

# Generate lighter and darker versions
lighter_colors <- lighten(ggplot_colors, amount = 0.3)  # Increase brightness
darker_colors  <- darken(ggplot_colors, amount = 0.3)   # Decrease brightness


correlation <- cor(combined$sum_eboxes_inside_cpg, combined$coverage_myc, method = "spearman", use = "complete.obs")

comparisons <- list(c("No E-box", "CACGTG"), c("No E-box", "CACGCG"), c("No E-box", "CATGCG"), c("No E-box", "CATGTG"), c("No E-box", "CACGAG"), c("No E-box", "CACATG"))

plot = ggplot(combined, aes(x = motif, y = coverage_myc)) +
  geom_boxplot(data = combined[combined$motif == "No E-box", ], color = "white") +
  geom_point(data = combined[combined$motif %in% ebox_motifs, ], aes(color = group_inside_cpg, fill = inside_cpg), size=0.5, alpha = 0.1, position = position_jitterdodge(jitter.width = 0.2)) +
  scale_color_manual(values = c(lighter_colors,  darker_colors, "black", "black"), guide = "none") +
  scale_size_manual(values = c("white", "white"), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined[combined$motif == "No E-box", ], color = "black", outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif %in% ebox_motifs, ], aes(color = group_inside_cpg), outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif == "2+ E-boxes", ],color = "chocolate3", outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors, darker_colors), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined[combined$motif == "CACGTG", ], aes(color = group_inside_cpg), outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors[1], darker_colors[1]), labels = c("FALSE", "TRUE"), guide = "legend") +
  labs(title = "Coverage_MYC Across Peaks highlighting 1 E-box Motif in Peak or CpG Island",
       x = "Motif",
       y = "Coverage_MYC",
       color = "E-box inside\nCpG Island") +
  geom_text(
    data = counts,
    aes(x = motif, y = -15, label = n), # Fixed y position
    size = 4,
    position = position_dodge(width = 0.9)
  )+ 
  annotate("text", x = 1, y = 130, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  stat_compare_means(method="wilcox.test", label = "p.signif", aes(group = inside_cpg), hide.ns = FALSE, label.y = rep(120)) +
  scale_y_continuous(breaks = seq(0, 240, 20), limits = c(-15, 130))
plot
ggsave("./box_coverage_max_1_ebox_in_vs_outside.svg", plot, width = 9, height = 6)


lfc_data = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")

merged = merge(lfc_data, group_by_motif, by="gene_id", all.x = TRUE)
merged = merged %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

merged$motif = ifelse(is.na(merged$sum_eboxes), "No Assigned Peak", as.character(merged$motif))

merged$motif = factor(merged$motif, levels = c("No Assigned Peak","No E-box", ebox_motifs, "2+ E-boxes"))

combined = merged



combined = combined %>% mutate(inside_cpg = case_when(
  sum_eboxes == 1 & sum_eboxes_inside_cpg == 1 ~ TRUE,
  sum_eboxes == 1 & sum_eboxes_inside_cpg == 0 ~ FALSE,
  TRUE ~ NA
))

combined_without_na = combined[!is.na(combined$sum_eboxes), ]

counts <- combined_without_na  %>%
  group_by(motif, inside_cpg) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(motif) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

combined_without_na$group_inside_cpg <- interaction(combined_without_na$motif, combined_without_na$inside_cpg)


correlation <- cor(combined_without_na$sum_eboxes_inside_cpg, combined_without_na$coverage_myc, method = "spearman", use = "complete.obs")

comparisons <- list(c("No E-box", "CACGTG"), c("No E-box", "CACGCG"), c("No E-box", "CATGCG"), c("No E-box", "CATGTG"), c("No E-box", "CACGAG"), c("No E-box", "CACATG"))

plot = ggplot(combined_without_na, aes(x = motif, y = coverage_myc)) +
  geom_point(data = combined_without_na[combined_without_na$motif == "No E-box", ], color = "white") +
  geom_point(data = combined_without_na[combined_without_na$motif %in% ebox_motifs, ], aes(color = group_inside_cpg, fill = inside_cpg), size=0.5, alpha = 0.1, position = position_jitterdodge(jitter.width = 0.2)) +
  scale_color_manual(values = c(lighter_colors,  darker_colors, "black", "black"), guide = "none") +
  scale_fill_manual(values = c("white", "white"), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined_without_na[combined_without_na$motif == "No E-box", ], color = "black", outliers = FALSE) +
  geom_boxplot(data = combined_without_na[combined_without_na$motif %in% ebox_motifs, ], aes(color = group_inside_cpg), outliers = FALSE) +
  geom_boxplot(data = combined_without_na[combined_without_na$motif == "2+ E-boxes", ],color = "chocolate3", outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors, darker_colors), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined_without_na[combined_without_na$motif == "CACGTG", ], aes(color = group_inside_cpg), outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors[1], darker_colors[1]), labels = c("FALSE", "TRUE"), guide = "legend") +
  labs(title = "Coverage_MYC Across Strongest Peaks highlighting 1 E-box Motif in Peak or CpG Island",
       x = "Motif",
       y = "Coverage_MYC",
       color = "E-box inside\nCpG Island") +
  geom_text(
    data = counts,
    aes(x = motif, y = -15, label = n), # Fixed y position
    size = 4,
    position = position_dodge(width = 0.9)
  )+ 
  annotate("text", x = 1, y = 150, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  stat_compare_means(method="wilcox.test", label = "p.signif", aes(group = inside_cpg), hide.ns = FALSE, label.y = 140) +
  scale_y_continuous(breaks = seq(0, 240, 20), limits = c(-15, 150))
plot
ggsave("./box_coverage_max_1_ebox_in_vs_outside_strongest.svg", plot, width = 9, height = 6)

counts <- combined  %>%
  group_by(motif, inside_cpg) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(motif) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

combined$group_inside_cpg <- interaction(combined$motif, combined$inside_cpg)


correlation <- cor(combined$sum_eboxes_inside_cpg, combined$log2FoldChange, method = "spearman", use = "complete.obs")

plot = ggplot(combined, aes(x = motif, y = log2FoldChange)) +
  geom_point(data = combined[combined$motif == "No Assigned Peak", ], color = "white") +
  geom_point(data = combined[combined$motif == "No E-box", ], color = "white") +
  geom_point(data = combined[combined$motif %in% ebox_motifs, ], aes(color = group_inside_cpg, fill = inside_cpg), size=0.5, alpha = 0.1, position = position_jitterdodge(jitter.width = 0.2)) +
  geom_point(data = combined[combined$motif == "2+ E-boxes", ], color = "chocolate3") +
  scale_color_manual(values = c(lighter_colors,  darker_colors, "black", "black"), guide = "none") +
  scale_fill_manual(values = c("white", "white"), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined[combined$motif == "No Assigned Peak", ], color = "grey", outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif == "No E-box", ], color = "black", outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif %in% ebox_motifs, ], aes(color = group_inside_cpg), outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif == "2+ E-boxes", ],color = "chocolate3", outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors, darker_colors), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined[combined$motif == "CACGTG", ], aes(color = group_inside_cpg), outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors[1], darker_colors[1]), labels = c("FALSE", "TRUE"), guide = "legend") +
  labs(title = "LFC Across Strongest Peaks highlighting 1 E-box Motif in Peak or CpG Island",
       x = "Motif",
       y = "-log2(Fold Change MYC vs. MYC Depletion)",
       color = "E-box inside\nCpG Island") +
  
  stat_compare_means(data = combined[combined$motif %in% ebox_motifs, ],
                     aes(x = motif, y = log2FoldChange, group = sum_eboxes_inside_cpg),
                     label = "p.signif", 
                     method = "wilcox.test",
                     label.y = rep(2.3, 6)
  )+
  geom_text(
    data = counts,
    aes(x = motif, y = -1.5, label = n),
    size = 4,
    position = position_dodge(width = 0.9)
  ) +
  annotate("text", x = 1, y = 2.5, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5)) + 
  scale_y_continuous(limits = c(-1.5, 2.5))
plot
ggsave("./box_lfc_max_1_ebox_in_vs_outside.svg", plot, width = 9, height = 6)



ebox_motifs <- c("CACGTG", "CACGCG", "CATGCG", "CATGTG", "CACGAG", "CACATG")

ebox_inside_cpg_names = paste0(ebox_motifs, "_inside_cpg")

group_by_motif = annotated_peaks[annotated_peaks$CpG_island, ]



group_by_motif$motif = ebox_motifs[apply(group_by_motif[, ebox_motifs], 1, which.max)]
group_by_motif$motif = ifelse(group_by_motif$sum_eboxes > 1, "2+ E-boxes", ifelse(group_by_motif$sum_eboxes == 0, "No E-box", group_by_motif$motif))

group_by_motif$motif = factor(group_by_motif$motif, levels = c("No E-box", ebox_motifs, "2+ E-boxes"))

combined = group_by_motif

combined = combined %>% mutate(inside_cpg = case_when(
  sum_eboxes == 1 & sum_eboxes_inside_cpg == 1 ~ TRUE,
  sum_eboxes == 1 & sum_eboxes_inside_cpg == 0 ~ FALSE,
  TRUE ~ NA
))

counts <- combined  %>%
  group_by(motif, inside_cpg) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(motif) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

combined$group_inside_cpg <- interaction(combined$motif, combined$inside_cpg)

library(colorspace)

# Define original ggplot2 colors
ggplot_colors <- scales::hue_pal()(length(ebox_motifs))

# Generate lighter and darker versions
lighter_colors <- lighten(ggplot_colors, amount = 0.3)  # Increase brightness
darker_colors  <- darken(ggplot_colors, amount = 0.3)   # Decrease brightness


correlation <- cor(combined$sum_eboxes_inside_cpg, combined$coverage_myc, method = "spearman", use = "complete.obs")

comparisons <- list(c("No E-box", "CACGTG"), c("No E-box", "CACGCG"), c("No E-box", "CATGCG"), c("No E-box", "CATGTG"), c("No E-box", "CACGAG"), c("No E-box", "CACATG"))

plot = ggplot(combined, aes(x = motif, y = coverage_myc)) +
  geom_point(data = combined[combined$motif == "No E-box", ], color = "white") +
  geom_point(data = combined[combined$motif %in% ebox_motifs, ], aes(color = group_inside_cpg, fill = inside_cpg), size=0.5, alpha = 0.1, position = position_jitterdodge(jitter.width = 0.2)) +
  scale_color_manual(values = c(lighter_colors,  darker_colors, "black", "black"), guide = "none") +
  scale_fill_manual(values = c("white", "white"), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined[combined$motif == "No E-box", ], color = "black", outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif %in% ebox_motifs, ], aes(color = group_inside_cpg), outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif == "2+ E-boxes", ],color = "chocolate3", outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors, darker_colors), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined[combined$motif == "CACGTG", ], aes(color = group_inside_cpg), outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors[1], darker_colors[1]), labels = c("FALSE", "TRUE"), guide = "legend") +
  labs(title = "Coverage_MYC Across Peaks in CpG Islands highlighting 1 E-box Motif in Peak or CpG Island",
       x = "Motif",
       y = "Coverage_MYC",
       color = "E-box inside\nCpG Island") +
  geom_text(
    data = counts,
    aes(x = motif, y = -15, label = n), # Fixed y position
    size = 4,
    position = position_dodge(width = 0.9)
  )+ 
  annotate("text", x = 1, y = 130, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(plot.title = element_text(hjust = 0.3)) +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  stat_compare_means(method="wilcox.test", label = "p.signif", aes(group = inside_cpg), hide.ns = FALSE, label.y = rep(120)) +
  scale_y_continuous(breaks = seq(0, 240, 20), limits = c(-15, 130))
plot
ggsave("./box_coverage_max_1_ebox_in_vs_outside_only_cpg.svg", plot, width = 9, height = 6)



group_by_motif = annotated_peaks

group_by_motif$motif = ebox_motifs[apply(group_by_motif[, ebox_motifs], 1, which.max)]
group_by_motif$motif = ifelse(group_by_motif$sum_eboxes > 1, "2+ E-boxes", ifelse(group_by_motif$sum_eboxes == 0, "No E-box", group_by_motif$motif))

group_by_motif$motif = factor(group_by_motif$motif, levels = c("No E-box", ebox_motifs, "2+ E-boxes"))

lfc_data = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")

merged = merge(lfc_data, group_by_motif, by="gene_id", all.x = TRUE)
merged = merged %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

merged = merged[is.na(merged$CpG_island) | merged$CpG_island, ]

merged$motif = ifelse(is.na(merged$sum_eboxes), "No Assigned Peak", as.character(merged$motif))

merged$motif = factor(merged$motif, levels = c("No Assigned Peak","No E-box", ebox_motifs, "2+ E-boxes"))

combined = merged



combined = combined %>% mutate(inside_cpg = case_when(
  sum_eboxes == 1 & sum_eboxes_inside_cpg == 1 ~ TRUE,
  sum_eboxes == 1 & sum_eboxes_inside_cpg == 0 ~ FALSE,
  TRUE ~ NA
))

combined_without_na = combined[!is.na(combined$sum_eboxes), ]

counts <- combined_without_na  %>%
  group_by(motif, inside_cpg) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(motif) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

combined_without_na$group_inside_cpg <- interaction(combined_without_na$motif, combined_without_na$inside_cpg)


correlation <- cor(combined_without_na$sum_eboxes_inside_cpg, combined_without_na$coverage_myc, method = "spearman", use = "complete.obs")

comparisons <- list(c("No E-box", "CACGTG"), c("No E-box", "CACGCG"), c("No E-box", "CATGCG"), c("No E-box", "CATGTG"), c("No E-box", "CACGAG"), c("No E-box", "CACATG"))

median_baseline = c(median(combined_without_na[combined_without_na$motif == "No E-box", ]$coverage_myc))


plot = ggplot(combined_without_na, aes(x = motif, y = coverage_myc)) +
  geom_boxplot(data = combined_without_na[combined_without_na$motif == "No E-box", ], color = "black", outliers = FALSE) +
  geom_point(data = combined_without_na[combined_without_na$motif %in% ebox_motifs, ], aes(color = group_inside_cpg, size = inside_cpg), alpha = 0.1, position = position_jitterdodge(jitter.width = 0.2)) +
  geom_point(data = combined_without_na[combined_without_na$motif == "2+ E-boxes", ], shape = 16, color = "chocolate3", size=0.7, alpha = 0.1, position = position_jitter(0.2)) +
  scale_color_manual(values = c(lighter_colors,  darker_colors, "black", "black"), guide = "none") +
  scale_size_manual(values = c(0.5, 0.5), guide = "none") +
  new_scale_color() +
  geom_hline(yintercept = median_baseline, linetype = "dashed", color = "black") +
  geom_boxplot(data = combined_without_na[combined_without_na$motif %in% ebox_motifs, ], aes(color = group_inside_cpg), outliers = FALSE) +
  geom_boxplot(data = combined_without_na[combined_without_na$motif == "2+ E-boxes", ],color = "chocolate3", outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors, darker_colors), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined_without_na[combined_without_na$motif == "CACGTG", ], aes(color = group_inside_cpg), outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors[1], darker_colors[1]), labels = c("FALSE", "TRUE"), guide = "legend") +
  labs(#title = "Coverage_MYC Across Strongest Peaks in CpG Islands highlighting 1 E-box Motif in Peak or CpG Island",
       x = "Motif",
       y = "MYC ChIP-seq Coverage",
       color = "E-box inside\nCpG Island") +
  geom_text(
    data = counts,
    aes(x = motif, y = -15, label = n), # Fixed y position
    size = 4,
    position = position_dodge(width = 0.9)
  )+ 
  theme_minimal()+ 
  guides(color = "none") +
  theme(plot.title = element_text(hjust = 0.3)) +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  stat_compare_means(method="wilcox.test", label = "p.signif", aes(group = inside_cpg), hide.ns = FALSE, label.y = 160) +
  scale_y_continuous(breaks = seq(0, 240, 20)) +
  coord_cartesian(ylim = c(-15, 160))
plot
ggsave("./box_coverage_max_1_ebox_in_vs_outside_strongest_only_cpg.pdf", plot, width = 9, height = 6)

counts <- combined  %>%
  group_by(motif, inside_cpg) %>%
  summarise(n = n(), .groups = "drop") %>%
  group_by(motif) %>%
  summarise(n = paste("n=", paste(n, collapse = ", "), sep = ""))

combined$group_inside_cpg <- interaction(combined$motif, combined$inside_cpg)


correlation <- cor(combined$sum_eboxes_inside_cpg, combined$log2FoldChange, method = "spearman", use = "complete.obs")

median_baseline = c(median(combined[combined$motif == "No E-box", ]$log2FoldChange))

plot = ggplot(combined, aes(x = motif, y = log2FoldChange)) +
  geom_boxplot(data = combined[combined$motif == "No Assigned Peak", ], color = "grey", outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif == "No E-box", ], color = "black", outliers = FALSE) +
  geom_point(data = combined[combined$motif %in% ebox_motifs, ], aes(color = group_inside_cpg, size = inside_cpg), alpha = 0.1, position = position_jitterdodge(jitter.width = 0.2)) +
  geom_point(data = combined_without_na[combined_without_na$motif == "2+ E-boxes", ], shape = 16, color = "chocolate3", size=0.7, alpha = 0.1, position = position_jitter(0.2)) +
  scale_color_manual(values = c(lighter_colors,  darker_colors, "black", "black"), guide = "none") +
  scale_size_manual(values = c(0.5, 0.5), guide = "none") +
  new_scale_color() +
  geom_hline(yintercept = median_baseline, linetype = "dashed", color = "black") +
  geom_boxplot(data = combined[combined$motif == "No Assigned Peak", ], color = "grey", outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif %in% ebox_motifs, ], aes(color = group_inside_cpg), outliers = FALSE) +
  geom_boxplot(data = combined[combined$motif == "2+ E-boxes", ],color = "chocolate3", outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors, darker_colors), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = combined[combined$motif == "CACGTG", ], aes(color = group_inside_cpg), outliers = FALSE) +
  scale_color_manual(values = c(lighter_colors[1], darker_colors[1]), labels = c("FALSE", "TRUE"), guide = "legend") +
  labs(#title = "LFC Across Strongest Peaks in CpG Islands highlighting 1 E-box Motif in Peak or CpG Island",
       x = "Motif",
       y = "-log2(Fold Change MYC vs. MYC Depletion)",
       color = "E-box inside\nCpG Island") +
  
  stat_compare_means(data = combined[combined$motif %in% ebox_motifs, ],
                     aes(x = motif, y = log2FoldChange, group = sum_eboxes_inside_cpg),
                     label = "p.signif", 
                     method = "wilcox.test",
                     label.y = rep(2.1, 6)
  )+
  geom_text(
    data = counts,
    aes(x = motif, y = -1.5, label = n),
    size = 4,
    position = position_dodge(width = 0.9)
  ) +
  guides(color = "none") +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5)) + 
  coord_cartesian(ylim = c(-1.5, 2.1))
plot
ggsave("./box_lfc_max_1_ebox_in_vs_outside_only_cpg.pdf", plot, width = 9, height = 6)


subset = subset[subset$source == "Inside CpG Island", ]

counts <- subset %>%
  group_by(motif) %>%
  summarise(n = paste("n=", n(), sep = ""))

comparisons <- list(c("No E-box", "CACGTG"), c("No E-box", "CACGCG"), c("No E-box", "CATGCG"), c("No E-box", "CATGTG"), c("No E-box", "CACGAG"), c("No E-box", "CACATG"))

ggplot(subset, aes(x = motif, y = coverage_myc)) +
  geom_boxplot(data = subset[subset$motif == "No E-box", ],outliers = FALSE) +
  geom_jitter(data = subset[as.character(subset$motif) %in% ebox_motifs, ], aes(color = motif), width = 0.2, alpha = 0.1) +
  geom_boxplot(data = subset[as.character(subset$motif) %in% ebox_motifs, ],outliers = FALSE, aes(color = motif)) +
  geom_jitter(data = subset[subset$motif == "2+ E-boxes", ], width = 0.2, alpha = 0.1, color="red") +
  geom_boxplot(data = subset[subset$motif == "2+ E-boxes", ],outliers = FALSE, color = "red") +
  labs(title = "Coverage_MYC Across Strongest Peaks with max 1 E-box Motif in CpG Islands",
       x = "Motif",
       y = "Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = motif, y = -10, label = n), # Fixed y position
    size = 4
  )+ 
  guides(color = "none") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = comparisons, hide.ns = FALSE, label.y = seq(160, 280, 20)) +
  scale_y_continuous(breaks = seq(0, 300, 20), limits = c(-10, 300))


counts <- merged %>%
  group_by(motif, source) %>%
  summarise(n = paste("n=", n(), sep = ""))

new_comparisons = append(comparisons, list(c("No Peak", "No single E-box"), c("No Peak", "No E-box")), after = 0)

ggplot(merged, aes(x = motif, y = log2FoldChange)) + 
  geom_boxplot(data = merged, aes(color = source), outliers = FALSE) +
  geom_jitter(data = merged[as.character(merged$motif) %in% ebox_motifs, ], aes(color = motif, fill = source), alpha = 0.1, position = position_jitterdodge(jitter.width = 0.2)) +
  geom_jitter(data = merged[merged$motif == "2+ E-boxes", ], aes(color = motif, fill = source), alpha = 0.1, color="red", position = position_jitterdodge(jitter.width = 0.2)) +
  scale_color_manual(values = c("white", "white", scales::hue_pal()(length(ebox_motifs))), guide = "none") +
  scale_fill_manual(values = c("white", "white"), guide = "none") +
  new_scale_color() +
  geom_boxplot(data = merged[merged$motif == "No Peak", ], color = "grey",outliers = FALSE) +
  geom_boxplot(data = merged[merged$motif == "No E-box", ], aes(color = source),outliers = FALSE) +
  geom_boxplot(data = merged[merged$motif != "No E-box" & merged$motif != "No Peak", ],outliers = FALSE, aes(color = source)) +
  labs(title = "LFC Across Genes for strongest Peaks with max 1 E-box Motif in Peak or CpG Island",
       x = "Motif",
       y = "-log2(Fold Change MYC vs. MYC Depletion)") +
  geom_text(
    data = counts,
    aes(x = motif, y = -1.5, group = source, label = n), # Fixed y position
    size = 4,
    position = position_dodge(width = 0.9)
  )+
  theme(panel.grid = element_blank())+
  theme_minimal()+
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  stat_compare_means(method="wilcox.test", label = "p.signif", aes(group = source), hide.ns = FALSE, label.y = rep(3.5, 8)) 



counts <- merged_inside_cpg %>%
  group_by(motif) %>%
  summarise(n = paste("n=", n(), sep = ""))


ggplot(merged_inside_cpg, aes(x = motif, y = log2FoldChange)) +
  geom_boxplot(data = merged_inside_cpg[merged_inside_cpg$motif == "No Peak", ], color = "grey", outliers = FALSE) +
  geom_boxplot(data = merged_inside_cpg[merged_inside_cpg$motif == "No E-box", ],outliers = FALSE) +
  geom_jitter(data = merged_inside_cpg[as.character(merged_inside_cpg$motif) %in% ebox_motifs, ], aes(color = motif), width = 0.2, alpha = 0.1) +
  geom_boxplot(data = merged_inside_cpg[as.character(merged_inside_cpg$motif) %in% ebox_motifs, ],outliers = FALSE, aes(color = motif)) +
  geom_jitter(data = merged_inside_cpg[merged_inside_cpg$motif == "2+ E-boxes", ], width = 0.2, alpha = 0.1, color="red") +
  geom_boxplot(data = merged_inside_cpg[merged_inside_cpg$motif == "2+ E-boxes", ],outliers = FALSE, color = "red") +
  labs(title = "Coverage_MYC Across Peaks with max 1 E-box Motif in CpG Islands",
       x = "Motif",
       y = "Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = motif, y = -3, label = n), # Fixed y position
    size = 4
  )+ 
  guides(color = "none") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = comparisons, hide.ns = FALSE) 
