# SPDX-FileCopyrightText: 2025 Julius Deynet <julius.deynet@stud-mail.uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

library(dplyr)
library(ggplot2)
library(scales)
library(grandR)
library(ggnewscale)

count_data <- read.delim("./resources/counts_all_replicas_new.txt", sep="\t", comment.char="#")

# Select only the columns that correspond to your sample counts
#count_data <- count_data[, c("IAA.ALK.A.TC.bam", "IAA.ALK.B.TC.bam", "IAA.ALK.C.TC.bam", "DMSO.ALK.A.TC.bam", "DMSO.ALK.B.TC.bam", "DMSO.ALK.C.TC.bam")]
count_data <- count_data[, c("Geneid", "IAA.ALK.A.bam", "IAA.ALK.B.bam", "IAA.ALK.C.bam", "DMSO.ALK.A.bam", "DMSO.ALK.B.bam", "DMSO.ALK.C.bam")]

# keep genes with at least 100 counts in at least three samples while retaining the gene_id
count_data <- count_data %>% filter(rowSums(dplyr::select(., -Geneid) >= 100) >= 3)

toKeep = count_data$Geneid

#saveRDS(toKeep, "./resources/talk-seq_genes_to_keep_new.rds")

library(org.Hs.eg.db)
library(AnnotationDbi)

# Map Ensembl IDs to gene symbols (official gene names)
gene_names <- mapIds(org.Hs.eg.db,
                     keys = count_data$Geneid,     # Ensembl IDs
                     column = "SYMBOL",           # Map to gene symbols
                     keytype = "ENSEMBL",         # The key is Ensembl IDs
                     multiVals = "first")         # In case of multiple mappings, take the first one

# Add the gene names to your results dataframe
count_data$gene_name <- gene_names

count_data_intron_tc <- read.delim("./resources/counts_all_replicas_introns_TC_new.txt", sep="\t", comment.char="#")
count_data_intron_tc <- count_data_intron_tc[,  c("Geneid", "IAA.ALK.A.TC.bam", "IAA.ALK.B.TC.bam", "IAA.ALK.C.TC.bam", "DMSO.ALK.A.TC.bam", "DMSO.ALK.B.TC.bam", "DMSO.ALK.C.TC.bam")]

# only keep the same genes as in count data
count_data_intron_tc <- count_data_intron_tc %>% filter(Geneid %in% count_data$Geneid)

# Map Ensembl IDs to gene symbols (official gene names)
gene_names <- mapIds(org.Hs.eg.db,
                     keys = count_data_intron_tc$Geneid,     # Ensembl IDs
                     column = "SYMBOL",           # Map to gene symbols
                     keytype = "ENSEMBL",         # The key is Ensembl IDs
                     multiVals = "first")         # In case of multiple mappings, take the first one

# Add the gene names to your results dataframe
count_data_intron_tc$gene_name <- gene_names


count_data_tc <- read.delim("./resources/counts_all_replicas_TC_new.txt", sep="\t", comment.char="#")
count_data_tc <- count_data_tc[,  c("Geneid", "IAA.ALK.A.TC.bam", "IAA.ALK.B.TC.bam", "IAA.ALK.C.TC.bam", "DMSO.ALK.A.TC.bam", "DMSO.ALK.B.TC.bam", "DMSO.ALK.C.TC.bam")]

# only keep the same genes as in count data
count_data_tc <- count_data_tc %>% filter(Geneid %in% count_data$Geneid)

# Map Ensembl IDs to gene symbols (official gene names)
gene_names <- mapIds(org.Hs.eg.db,
                     keys = count_data_tc$Geneid,     # Ensembl IDs
                     column = "SYMBOL",           # Map to gene symbols
                     keytype = "ENSEMBL",         # The key is Ensembl IDs
                     multiVals = "first")         # In case of multiple mappings, take the first one

# Add the gene names to your results dataframe
count_data_tc$gene_name <- gene_names


count_data_intron <- read.delim("./resources/counts_all_replicas_introns_new.txt", sep="\t", comment.char="#")
count_data_intron <- count_data_intron[,  c("Geneid", "IAA.ALK.A.TC.bam", "IAA.ALK.B.TC.bam", "IAA.ALK.C.TC.bam", "DMSO.ALK.A.TC.bam", "DMSO.ALK.B.TC.bam", "DMSO.ALK.C.TC.bam")]

# only keep the same genes as in count data
count_data_intron <- count_data_intron %>% filter(Geneid %in% count_data$Geneid)

# Map Ensembl IDs to gene symbols (official gene names)
gene_names <- mapIds(org.Hs.eg.db,
                     keys = count_data_intron$Geneid,     # Ensembl IDs
                     column = "SYMBOL",           # Map to gene symbols
                     keytype = "ENSEMBL",         # The key is Ensembl IDs
                     multiVals = "first")         # In case of multiple mappings, take the first one

# Add the gene names to your results dataframe
count_data_intron$gene_name <- gene_names


single_cell_data = readRDS("./resources/pseudobulk_MYC.rds")

single_cell_data = subset(single_cell_data, Coldata(single_cell_data, "Sample") == "A375")

single_cell_data = FilterGenes(single_cell_data)

sc_counts = as.data.frame(GetMatrix(single_cell_data, "norm"))
sc_new_counts = as.data.frame(GetMatrix(single_cell_data, "new.count"))
sc_counts$gene_name = rownames(sc_counts)
sc_new_counts$gene_name = rownames(sc_new_counts)

# add up the counts for each gene across the replicates for the two conditions
count_data_intron_tc = count_data_intron_tc %>% rowwise() %>% mutate(IAA = sum(c(IAA.ALK.A.TC.bam, IAA.ALK.B.TC.bam, IAA.ALK.C.TC.bam)),
                                                  DMSO = sum(c(DMSO.ALK.A.TC.bam, DMSO.ALK.B.TC.bam, DMSO.ALK.C.TC.bam)))
count_data = count_data %>% rowwise() %>% mutate(IAA = sum(c(IAA.ALK.A.bam, IAA.ALK.B.bam, IAA.ALK.C.bam)),
                                                 DMSO = sum(c(DMSO.ALK.A.bam, DMSO.ALK.B.bam, DMSO.ALK.C.bam)))
count_data_tc = count_data_tc %>% rowwise() %>% mutate(IAA = sum(c(IAA.ALK.A.TC.bam, IAA.ALK.B.TC.bam, IAA.ALK.C.TC.bam)),
                                                                     DMSO = sum(c(DMSO.ALK.A.TC.bam, DMSO.ALK.B.TC.bam, DMSO.ALK.C.TC.bam)))
count_data_intron = count_data_intron %>% rowwise() %>% mutate(IAA = sum(c(IAA.ALK.A.bam, IAA.ALK.B.bam, IAA.ALK.C.bam)),
                                                 DMSO = sum(c(DMSO.ALK.A.bam, DMSO.ALK.B.bam, DMSO.ALK.C.bam)))
sc_counts = sc_counts %>% rowwise() %>% mutate(IAA = sum(c(A375.Aux.4sU.A, A375.Aux.4sU.B, A375.Aux.4sU.C)),
                                               DMSO = sum(c(A375.DMSO.4sU.A, A375.DMSO.4sU.B, A375.DMSO.4sU.C)))
sc_new_counts = sc_new_counts %>% rowwise() %>% mutate(IAA = sum(c(A375.Aux.4sU.A, A375.Aux.4sU.B, A375.Aux.4sU.C)),
                                                       DMSO = sum(c(A375.DMSO.4sU.A, A375.DMSO.4sU.B, A375.DMSO.4sU.C)))


myc_signature <- read.csv("./resources/MYC_signature.csv", stringsAsFactors = FALSE)

create_expression_plot = function(toUse, name) {

# Check for MYC signature genes in your DESeq2 results
toUse$MYC_signature <- ifelse(toUse$gene_name %in% myc_signature$`HGNC.gene.symbol`, "MYC_signature", "Other")

total_counts = colSums(toUse[, c("IAA", "DMSO")])

threshold <- 0.000005
log_intercept <- log10(2)

toUse = toUse %>% mutate(IAA_percentage = IAA/total_counts["IAA"],
                                   DMSO_percentage = DMSO/total_counts["DMSO"])
toUse$density = density2d(log10(toUse$IAA), log10(toUse$DMSO))

x_min = min(toUse$IAA, na.rm = TRUE)
y_max = max(toUse$DMSO, na.rm = TRUE)

correlation1 = cor(toUse$IAA, toUse$DMSO, method = "pearson")
correlation1 = cor(toUse$IAA, toUse$DMSO, method = "spearman")

ggplot(toUse, aes(x = IAA, y = DMSO)) +
  geom_point(aes(color = density), size = 0.5) +
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color() +
  geom_point(data = toUse[toUse$MYC_signature == "MYC_signature", ], size = 0.5, aes(color = "MYC Signature")) +
  scale_color_manual(values = c("MYC Signature" = "red"), name = "") +
  scale_x_log10() +  # Log scale with percentage labels
  scale_y_log10() +
  new_scale_color() +
  
  # Add a trendline
  geom_smooth(method = "lm", aes(color = "Trendline"), se = FALSE) + # 'lm' for a linear model
  
  # Add a line with slope = 1 and intercept = 0
  geom_abline(slope = 1, intercept = 0, color = "black", linetype = "dashed") +
  geom_abline(aes(color = "2x Expression Threshold",
                  intercept =  -log10(2),  # Log10(2) as intercept
                  slope = 1),
              linetype = "dashed") +
  geom_abline(aes(color = "2x Expression Threshold",
                  intercept =  log10(2),  # Log10(2) as intercept
                  slope = 1),
              linetype = "dashed") +
  annotate("text", x = x_min + 1, y = y_max, 
           label = paste0("r = ", round(correlation1, 2), ", p = ", round(correlation2, 2)), 
           hjust = 0, vjust = 0, size = 4, color = "black") +
  scale_color_manual(values = c("Trendline" = "blue", "2x Expression Threshold" = "blue"), name = "") +
  annotation_logticks(sides = "bl") +  # Add ticks to bottom and left axes
  labs(
    x = "Expression MYC Depletion",
    y = "Expression MYC",
    #title = paste("Expression Levels: MYC Depletion vs MYC from", name, "data")
  ) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme(plot.title = element_text(hjust = 0.5))
}
plot = create_expression_plot(count_data, "exonic Talk-seq")
plot
ggsave("./expression_leveles_talk.pdf", plot, width = 9, height = 6)
plot = create_expression_plot(count_data_intron_tc, "intronic TC Talk-seq")
plot
ggsave("./expression_leveles_tc_intronic_talk.pdf", plot, width = 9, height = 6)
plot = create_expression_plot(count_data_intron, "intronic Talk-seq")
plot
ggsave("./expression_leveles_intronic_talk.pdf", plot, width = 9, height = 6)
plot = create_expression_plot(count_data_tc, "TC Talk-seq")
plot
ggsave("./expression_leveles_tc_talk.pdf", plot, width = 9, height = 6)
plot = create_expression_plot(sc_counts, "scSLAM-seq")
plot
ggsave("./expression_leveles_slam.pdf", plot, width = 9, height = 6)
plot = create_expression_plot(sc_new_counts, "new scSLAM-seq")
plot
ggsave("./expression_leveles_new_slam.pdf", plot, width = 9, height = 6)


yannotated_peaks = as.data.frame(read.delim("./resources/annotated_peaks.tsv"))

top_10th_percentile <- quantile(annotated_peaks$coverage_myc, 0.9)

annotated_peaks_top10p = annotated_peaks[annotated_peaks$coverage_myc >= top_10th_percentile, ]


merged = merge(count_data, annotated_peaks, by.x = "gene_id", by.y = "gene_id")

merged$is_top10p <- merged$coverage_myc >= top_10th_percentile

merged_top10p = merged[merged$is_top10p, ]




ggplot(merged, aes(x = IAA, y = DMSO)) +
  geom_point(data = merged[merged$number_of_cacgtg_eboxes == 0, ], alpha = 0.5, size = 1, color = "blue") +
  geom_point(data = merged[merged$number_of_cacgtg_eboxes > 0, ], alpha = 0.5, size = 1, color = "red") +
  scale_x_log10(labels = label_percent(), limits = c(0.000005, 0.01)) +  # Log scale with percentage labels
  scale_y_log10(labels = label_percent(), limits = c(0.000005, 0.01)) +
  
  # Add a trendline
  geom_smooth(method = "lm", color = "blue", se = FALSE) + # 'lm' for a linear model
  
  # Add a trendline
  geom_smooth(data = merged[merged$is_top10p, ], method = "lm", color = "red", se = FALSE) + # 'lm' for a linear model
  
  # Add a line with slope = 1 and intercept = 0
  geom_abline(slope = 1, intercept = 0, color = "black", linetype = "dashed") +
  geom_abline(
    intercept = c(log_intercept, -log_intercept),  # Log10(3) as intercept
    slope = 1,                  # Slope of the line
    color = "red",              # Line color
    linetype = "dashed"         # Line style
  ) +
  annotation_logticks(sides = "bl") +  # Add ticks to bottom and left axes
  
  labs(
    x = "Expression (% of Input, MYC_KO)",
    y = "Expression (% of Input, MYC)",
    title = "Expression Levels: MYC_KO vs MYC (Percentage of Input)"
  ) +
  theme_minimal()


ggplot(merged, aes(x = IAA, y = DMSO)) +
  geom_point(data = merged[!merged$is_top10p, ], alpha = 0.5, size = 1, color = "blue") +
  geom_point(data = merged[merged$is_top10p, ], alpha = 0.5, size = 1, color = "red") +
  scale_x_log10(labels = label_percent(), limits = c(0.000005, 0.01)) +  # Log scale with percentage labels
  scale_y_log10(labels = label_percent(), limits = c(0.000005, 0.01)) +
  
  # Add a trendline
  geom_smooth(method = "lm", color = "blue", se = FALSE) + # 'lm' for a linear model
  
  # Add a trendline
  geom_smooth(data = merged[merged$is_top10p, ], method = "lm", color = "red", se = FALSE) + # 'lm' for a linear model
  
  # Add a line with slope = 1 and intercept = 0
  geom_abline(slope = 1, intercept = 0, color = "black", linetype = "dashed") +
  geom_abline(
    intercept = c(log_intercept, -log_intercept),  # Log10(3) as intercept
    slope = 1,                  # Slope of the line
    color = "red",              # Line color
    linetype = "dashed"         # Line style
  ) +
  annotation_logticks(sides = "bl") +  # Add ticks to bottom and left axes
  
  labs(
    x = "Expression (% of Input, MYC_KO)",
    y = "Expression (% of Input, MYC)",
    title = "Expression Levels: MYC_KO vs MYC (Percentage of Input)"
  ) +
  theme_minimal()
