# SPDX-FileCopyrightText: 2025 Julius Deynet <julius.deynet@stud-mail.uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

library("DESeq2")

# Read the file, but keep only the relevant columns (Geneid and counts)
count_data <- read.delim("./resources/counts_all_replicas_introns_TC_new.txt", sep="\t", comment.char="#", row.names=1)

# Select only the columns that correspond to your sample counts
count_data <- count_data[, c("IAA.ALK.A.TC.bam", "IAA.ALK.B.TC.bam", "IAA.ALK.C.TC.bam", "DMSO.ALK.A.TC.bam", "DMSO.ALK.B.TC.bam", "DMSO.ALK.C.TC.bam")]

# Create a metadata frame with information about the samples
condition <- factor(c("MYC_KO", "MYC_KO", "MYC_KO", "MYC", "MYC", "MYC"), levels = c("MYC_KO", "MYC"))

colData <- data.frame(row.names = colnames(count_data), condition)

# Create the DESeqDataSet object
dds <- DESeqDataSetFromMatrix(countData = count_data, colData = colData, design = ~condition)

# Run the DESeq2 differential expression analysis
dds <- DESeq(dds)
res <- results(dds)

# View results
summary(res)

res = as.data.frame(res)

# Save the results to a CSV file
#write.csv(as.data.frame(res), file="./DESeq2_results_introns_TC_new.csv")



# Read the file, but keep only the relevant columns (Geneid and counts)
count_data <- read.delim("./resources/counts_all_replicas_TC_new.txt", sep="\t", comment.char="#", row.names=1)

# Select only the columns that correspond to your sample counts
count_data <- count_data[, c("IAA.ALK.A.TC.bam", "IAA.ALK.B.TC.bam", "IAA.ALK.C.TC.bam", "DMSO.ALK.A.TC.bam", "DMSO.ALK.B.TC.bam", "DMSO.ALK.C.TC.bam")]

# Create a metadata frame with information about the samples
condition <- factor(c("MYC_KO", "MYC_KO", "MYC_KO", "MYC", "MYC", "MYC"), levels = c("MYC_KO", "MYC"))

colData <- data.frame(row.names = colnames(count_data), condition)

# Create the DESeqDataSet object
dds <- DESeqDataSetFromMatrix(countData = count_data, colData = colData, design = ~condition)

# Run the DESeq2 differential expression analysis
dds <- DESeq(dds)
res <- results(dds)

# View results
summary(res)

res = as.data.frame(res)

# Save the results to a CSV file
#write.csv(as.data.frame(res), file="./DESeq2_results_TC_new.csv")




# Read the file, but keep only the relevant columns (Geneid and counts)
count_data <- read.delim("./resources/counts_all_replicas_introns_new.txt", sep="\t", comment.char="#", row.names=1)

# Select only the columns that correspond to your sample counts
count_data <- count_data[, c("IAA.ALK.A.bam", "IAA.ALK.B.bam", "IAA.ALK.C.bam", "DMSO.ALK.A.bam", "DMSO.ALK.B.bam", "DMSO.ALK.C.bam")]

# Create a metadata frame with information about the samples
condition <- factor(c("MYC_KO", "MYC_KO", "MYC_KO", "MYC", "MYC", "MYC"), levels = c("MYC_KO", "MYC"))

colData <- data.frame(row.names = colnames(count_data), condition)

# Create the DESeqDataSet object
dds <- DESeqDataSetFromMatrix(countData = count_data, colData = colData, design = ~condition)

# Run the DESeq2 differential expression analysis
dds <- DESeq(dds)
res <- results(dds)

# View results
summary(res)

res = as.data.frame(res)

# Save the results to a CSV file
write.csv(as.data.frame(res), file="./DESeq2_results_introns_new.csv")



# Read the file, but keep only the relevant columns (Geneid and counts)
count_data <- read.delim("./resources/counts_all_replicas_new.txt", sep="\t", comment.char="#", row.names=1)

# Select only the columns that correspond to your sample counts
count_data <- count_data[, c("IAA.ALK.A.bam", "IAA.ALK.B.bam", "IAA.ALK.C.bam", "DMSO.ALK.A.bam", "DMSO.ALK.B.bam", "DMSO.ALK.C.bam")]

# Create a metadata frame with information about the samples
condition <- factor(c("MYC_KO", "MYC_KO", "MYC_KO", "MYC", "MYC", "MYC"), levels = c("MYC_KO", "MYC"))

colData <- data.frame(row.names = colnames(count_data), condition)

# Create the DESeqDataSet object
dds <- DESeqDataSetFromMatrix(countData = count_data, colData = colData, design = ~condition)

# Run the DESeq2 differential expression analysis
dds <- DESeq(dds)
res <- results(dds)

# View results
summary(res)

res = as.data.frame(res)

# Save the results to a CSV file
write.csv(as.data.frame(res), file="./DESeq2_results_new.csv")




# Load required libraries
library(ggplot2)
library(ggrepel)

# Create a dataframe from results for easier manipulation
res_df = read.csv("./resources/DESeq2_results.csv")
res_df$logPvalue <- -log2(ifelse(is.na(res_df$padj), res_df$pvalue, res_df$padj))

# Define thresholds for labeling genes
threshold <- res_df$padj < 0.01 & abs(res_df$log2FoldChange) > 2

res_df$logPadj_capped <- pmin(res_df$logPvalue, 100)

toUse <- res_df

# Volcano plot with gene labels for especially significant genes

# Count genes in each region
counts <- toUse %>% mutate(
  region = case_when(
    logPadj_capped >= logPadj_threshold & log2FoldChange >= log2FoldChange_threshold ~ "Upper Right",
    logPadj_capped >= logPadj_threshold & log2FoldChange <= -log2FoldChange_threshold ~ "Upper Left",
    logPadj_capped < logPadj_threshold & log2FoldChange >= log2FoldChange_threshold ~ "Lower Right",
    logPadj_capped < logPadj_threshold & log2FoldChange <= -log2FoldChange_threshold ~ "Lower Left",
    TRUE ~ "Other"
  )
) %>%
  group_by(region) %>%
  summarize(count = n(), .groups = "drop")

x_range <- range(toUse$log2FoldChange, na.rm = TRUE)
y_range <- range(toUse$logPadj_capped, na.rm = TRUE)

ggplot(toUse, aes(x = log2FoldChange, y = logPadj_capped)) +
  geom_point() +
  
  geom_hline(yintercept = logPadj_threshold, linetype = "dashed", color = "blue") +
  geom_vline(xintercept = c(-log2FoldChange_threshold, log2FoldChange_threshold), 
             linetype = "dashed", color = "blue") +
  theme_minimal() +
  labs(x = "-log2(Fold Change MYC vs. MYC Depletion)", y = "-log10(p-adj) (capped at 100)", 
       title = "DESeq2 Analysis of Talk-seq Data") +
  #center title
  theme(plot.title = element_text(hjust = 0.5)) +
  
  coord_cartesian(xlim = c(x_range[1] - 0.7, x_range[2] + 0.7), 
                  ylim = c(y_range[1] - 1, y_range[2] + 1)) +
  
  # Add corner annotations
  annotate("text", x = x_range[2] +0.1, y = y_range[2] + 0.5, 
           label = paste("Upper Right\nGenes:", counts$count[counts$region == "Upper Right"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = x_range[1] -1, y = y_range[2] + 0.5, 
           label = paste("Upper Left\nGenes:", counts$count[counts$region == "Upper Left"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = x_range[2] + 0.1, y = y_range[1] - 3, 
           label = paste("Lower Right\nGenes:", counts$count[counts$region == "Lower Right"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = x_range[1] -1, y = y_range[1] - 3, 
           label = paste("Lower Left\nGenes:", counts$count[counts$region == "Lower Left"]),
           color = "black", size = 3, hjust = 0)

head(res_df)

library(org.Hs.eg.db)
library(AnnotationDbi)

# Create a dataframe from DESeq2 results
res_df <- as.data.frame(res)

# Extract ENSEMBL IDs (rownames) and map them to gene symbols
# Assuming your result dataframe 'res_df' has ENSG IDs as rownames

# Map Ensembl IDs to gene symbols (official gene names)
gene_names <- mapIds(org.Hs.eg.db,
                     keys = res_df$X,     # Ensembl IDs
                     column = "SYMBOL",           # Map to gene symbols
                     keytype = "ENSEMBL",         # The key is Ensembl IDs
                     multiVals = "first")         # In case of multiple mappings, take the first one

# Add the gene names to your results dataframe
res_df$gene_name <- gene_names

# Replace missing gene names (if any) with the Ensembl ID
res_df$gene_name[is.na(res_df$gene_name)] <- res_df$X[is.na(res_df$gene_name)]

# Now 'res_df' contains a new column 'gene_name' with either the gene name or the Ensembl ID


# View the dataframe with gene symbols
head(res_df)

res_df$logPvalue <- -log10(ifelse(is.na(res_df$padj), res_df$pvalue, res_df$padj))

ggplot(res_df, aes(x=log2FoldChange, y=logPvalue)) +
  geom_point(aes(color = padj < 0.05), size = 1.5) +   # Color significant genes
  geom_text_repel(data = res_df[threshold, ], aes(label = gene_name), size = 3, max.overlaps = 10) +  # Add gene names as labels
  theme_minimal() +
  labs(x = "MYC vs. MYC_Depleted LFC", y = "-log10(p-adj)") +
  scale_color_manual(values = c("black", "red")) 



# Load the MYC signature genes CSV file
myc_signature <- read.csv("./resources/MYC_signature.csv", stringsAsFactors = FALSE)

# Take a quick look at the data
head(myc_signature)

# Check for MYC signature genes in your DESeq2 results
res_df$MYC_signature <- ifelse(res_df$gene_name %in% myc_signature$`HGNC.gene.symbol`, "MYC_signature", "Other")

length(res_df[res_df$gene_name == "MYC_signature"])

# Load required libraries
library(ggplot2)
library(ggrepel)

# Create a dataframe for easier manipulation
res_df$logPvalue <- -log10(ifelse(is.na(res_df$padj), res_df$pvalue, res_df$padj))

# Define thresholds for labeling genes (adjust as needed)
threshold <- res_df$padj < 0.01 & abs(res_df$log2FoldChange) > 2

res_df$significant <- ifelse(!is.na(res_df$padj) & res_df$padj < 0.05, "Significant", "Not_Significant")


# Define thresholds for labeling genes (adjust as needed)
threshold <- res_df$padj < 0.01 & abs(res_df$log2FoldChange) > 2

# Volcano plot highlighting MYC signature genes with a legend
ggplot(res_df, aes(x = log2FoldChange, y = logPadj_capped)) +
  
  # Plot the non-MYC signature genes first (background)
  geom_point(data = res_df[res_df$MYC_signature == "Other", ], 
             aes(color = MYC_signature), size = 1.5) +
  
  # Plot the MYC signature genes on top (foreground)
  geom_point(data = res_df[res_df$MYC_signature == "MYC_signature", ], 
             aes(color = MYC_signature), size = 1.5) +
  
  # Customize plot appearance
  theme_minimal() +
  labs(x = "Log2 Fold Change", y = "-log10(p-value)", 
       title = "Volcano Plot Highlighting MYC Signature Genes") +
  
  # Define colors for the MYC signature and other genes
  scale_color_manual(values = c("Other" = "black", "MYC_signature" = "red"), 
                     labels = c("MYC signature genes", "Other genes"), 
                     name = "Gene Category") +
  
  # Add legend positioning and style (optional)
  theme(legend.position = "right")

# Define the thresholds
logPadj_threshold <- -log10(0.05)
log2FoldChange_threshold <- 1


lfc_data = readRDS("./resources/processed_featureCounts_data.rds")
lfc_TC_intron_data = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")
lfc_intron_data = readRDS("./resources/processed_featureCounts_introns_data.rds")
lfc_TC_data = readRDS("./resources/processed_featureCounts_TC_data.rds")

library(dplyr)
library(tidyr)

create_volcano_talk = function(data, data_name) { 

data$logPadj_capped <- pmin(data$logPadj, 100)

# Extend the range for annotation space
x_range <- range(data$log2FoldChange, na.rm = TRUE)
y_range <- range(data$logPadj_capped, na.rm = TRUE)


logPadj_threshold <- 1.3
log2FoldChange_threshold <- 1

# Count genes in each region
counts <- data %>% mutate(
    region = case_when(
      logPadj >= logPadj_threshold & log2FoldChange >= log2FoldChange_threshold ~ "Upper Right",
      logPadj >= logPadj_threshold & log2FoldChange <= -log2FoldChange_threshold ~ "Upper Left",
      logPadj < logPadj_threshold & log2FoldChange >= log2FoldChange_threshold ~ "Lower Right",
      logPadj < logPadj_threshold & log2FoldChange <= -log2FoldChange_threshold ~ "Lower Left",
      TRUE ~ "Other"
    )
  ) %>%
  group_by(region, MYC_signature) %>%
  summarize(count = n(), .groups = "drop") %>%
  complete(region = c("Upper Right", "Upper Left", "Lower Right", "Lower Left"), 
           MYC_signature = c("MYC_signature", "Other"), 
           fill = list(count = 0))

threshold <- data$significance == "Significant" & abs(data$log2FoldChange) > 1


data$density = density2d(data$log2FoldChange, data$logPadj_capped)

ggplot(data, aes(x = log2FoldChange, y = logPadj_capped)) +
  geom_point(data = data[data$MYC_signature == "Other", ], 
             aes(color = density), size = 1.5) +
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color() +
  geom_point(data = data[data$MYC_signature == "MYC_signature", ], 
             aes(color = MYC_signature), size = 1.5) +
  geom_hline(yintercept = logPadj_threshold, linetype = "dashed", color = "blue") +
  geom_vline(xintercept = c(-log2FoldChange_threshold, log2FoldChange_threshold), 
             linetype = "dashed", color = "blue") +
  theme_minimal() +
  labs(x = "-log2(Fold Change MYC vs. MYC Depletion)", y = "-log10(p-adj) (capped at 100)", 
       title = data_name) +
  theme(plot.title = element_text(hjust = 0.5)) +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  scale_color_manual(values = c("Other" = "black", "MYC_signature" = "red"),
                     labels = c("MYC signature genes", "Other genes"), 
                     name = "") +
  theme(legend.position = "right") +
  guides(color = guide_legend(order = 1), 
         fill = guide_colorbar(order = 2)) +
  
  # Extend the coordinate limits slightly to allow space for annotations
  coord_cartesian(xlim = c(-5, 5.2), 
                  ylim = c(0, y_range[2] + 0.7)) +
  
  # Add corner annotations
  annotate("text", x = 4.5, y = y_range[2], 
           label = paste("Upper Right\nMYC:", counts$count[counts$region == "Upper Right" & counts$MYC_signature == "MYC_signature"],
                         "\nOther:", counts$count[counts$region == "Upper Right" & counts$MYC_signature == "Other"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = -5, y = y_range[2] , 
           label = paste("Upper Left\nMYC:", counts$count[counts$region == "Upper Left" & counts$MYC_signature == "MYC_signature"],
                         "\nOther:", counts$count[counts$region == "Upper Left" & counts$MYC_signature == "Other"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = 4.5, y =  0, 
           label = paste("Lower Right\nMYC:", counts$count[counts$region == "Lower Right" & counts$MYC_signature == "MYC_signature"],
                         "\nOther:", counts$count[counts$region == "Lower Right" & counts$MYC_signature == "Other"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = -5, y =  0, 
           label = paste("Lower Left\nMYC:", counts$count[counts$region == "Lower Left" & counts$MYC_signature == "MYC_signature"],
                         "\nOther:", counts$count[counts$region == "Lower Left" & counts$MYC_signature == "Other"]),
           color = "black", size = 3, hjust = 0) +
  scale_x_continuous(breaks = seq(-5, 5, 1))


}

plot = create_volcano_talk(lfc_data, "exonic Talk-seq")
ggsave("./volcano_plot_talk_seq.pdf", plot, width = 9, height = 6)
plot = create_volcano_talk(lfc_TC_intron_data, "intronic TC Talk-seq")
ggsave("./vulcano_signature_tc_intronic_talk.pdf", plot, width = 9, height = 6)

plot = create_volcano_talk(lfc_data, "TC Talk-seq")
ggsave("./vulcano_signature_tc_talk.svg", plot, width = 9, height = 6)
plot = create_volcano_talk(lfc_TC_intron_data, "intronic Talk-seq")
ggsave("./vulcano_signature_intronic_talk.svg", plot, width = 9, height = 6)

lfc_sc_new_data = readRDS("./resources/processed_grandR_single_cell_new_data.rds")
lfc_sc_data = readRDS("./resources/processed_grandR_single_cell_total_data.rds")


create_volcano_slam = function(data, data_name) { 

data$logPadj_capped <- pmin(data$logPadj, 100)

# Extend the range for annotation space
x_range <- range(data$log2FoldChange, na.rm = TRUE)
y_range <- range(data$logPadj_capped, na.rm = TRUE)


logPadj_threshold <- 1.3
log2FoldChange_threshold <- 1

# Count genes in each region
counts <- data %>% mutate(
  region = case_when(
    logPadj >= logPadj_threshold & log2FoldChange >= log2FoldChange_threshold ~ "Upper Right",
    logPadj >= logPadj_threshold & log2FoldChange <= -log2FoldChange_threshold ~ "Upper Left",
    logPadj < logPadj_threshold & log2FoldChange >= log2FoldChange_threshold ~ "Lower Right",
    logPadj < logPadj_threshold & log2FoldChange <= -log2FoldChange_threshold ~ "Lower Left",
    TRUE ~ "Other"
  )
) %>%
  group_by(region, MYC_signature) %>%
  summarize(count = n(), .groups = "drop") %>%
  complete(region = c("Upper Right", "Upper Left", "Lower Right", "Lower Left"), 
           MYC_signature = c("MYC_signature", "Other"), 
           fill = list(count = 0))

threshold <- data$significance == "Significant" & abs(data$log2FoldChange) > 1



data$density = density2d(data$log2FoldChange, data$logPadj_capped)

ggplot(data, aes(x = log2FoldChange, y = logPadj_capped)) +
  geom_point(data = data[data$MYC_signature == "Other", ], 
             aes(color = density), size = 1.5) +
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color() +
  geom_point(data = data[data$MYC_signature == "MYC_signature", ], 
             aes(color = MYC_signature), size = 1.5) +
  geom_hline(yintercept = logPadj_threshold, linetype = "dashed", color = "blue") +
  geom_vline(xintercept = c(-log2FoldChange_threshold, log2FoldChange_threshold), 
             linetype = "dashed", color = "blue") +
  theme_minimal() +
  labs(x = "-log2(Fold Change MYC vs. MYC Depletion)", y = "-log10(p-adj) (capped at 100)", 
       title = data_name) +
  theme(plot.title = element_text(hjust = 0.5)) +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  scale_color_manual(values = c("Other" = "black", "MYC_signature" = "red"),
                     labels = c("MYC signature genes", "Other genes"), 
                     name = "") +
  theme(legend.position = "right") +
  guides(color = guide_legend(order = 1), 
         fill = guide_colorbar(order = 2)) +
  
  # Extend the coordinate limits slightly to allow space for annotations
  coord_cartesian(xlim = c(-2.4, 2.4), 
                  ylim = c(0, y_range[2] + 0.7)) +
  
  # Add corner annotations
  annotate("text", x = 2.1, y = y_range[2], 
           label = paste("Upper Right\nMYC:", counts$count[counts$region == "Upper Right" & counts$MYC_signature == "MYC_signature"],
                         "\nOther:", counts$count[counts$region == "Upper Right" & counts$MYC_signature == "Other"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = -2.5, y = y_range[2] , 
           label = paste("Upper Left\nMYC:", counts$count[counts$region == "Upper Left" & counts$MYC_signature == "MYC_signature"],
                         "\nOther:", counts$count[counts$region == "Upper Left" & counts$MYC_signature == "Other"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = 2.1, y =  0, 
           label = paste("Lower Right\nMYC:", counts$count[counts$region == "Lower Right" & counts$MYC_signature == "MYC_signature"],
                         "\nOther:", counts$count[counts$region == "Lower Right" & counts$MYC_signature == "Other"]),
           color = "black", size = 3, hjust = 0) +
  
  annotate("text", x = -2.5, y =  0, 
           label = paste("Lower Left\nMYC:", counts$count[counts$region == "Lower Left" & counts$MYC_signature == "MYC_signature"],
                         "\nOther:", counts$count[counts$region == "Lower Left" & counts$MYC_signature == "Other"]),
           color = "black", size = 3, hjust = 0) +
  scale_x_continuous(breaks = seq(-6, 6, 1))

}

plot = create_volcano_slam(lfc_sc_data, "scSLAM-seq")
ggsave("./vulcano_signature_slam.pdf", plot, width = 9, height = 6)
plot = create_volcano_slam(lfc_sc_new_data, "new scSLAM-seq")
ggsave("./vulcano_signature_new_slam.pdf", plot, width = 9, height = 6)



talk_seq_data = readRDS("./resources/processed_featureCounts_data.rds")
talk_seq_data_TC_intron = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")
slam_seq_data = readRDS("./resources/processed_grandR_single_cell_total_data.rds")
slam_seq_data_new = readRDS("./resources/processed_grandR_single_cell_new_data.rds")

talk_seq_data = talk_seq_data[, c("log2FoldChange", "MYC_signature")]
talk_seq_data_TC_intron = talk_seq_data_TC_intron[, c("log2FoldChange", "MYC_signature")]
slam_seq_data = slam_seq_data[, c("log2FoldChange", "MYC_signature")]
slam_seq_data_new = slam_seq_data_new[, c("log2FoldChange", "MYC_signature")]

talk_seq_data$source = "Talk-seq"
talk_seq_data_TC_intron$source = "intronic TC Talk-seq"
slam_seq_data$source = "scSLAM-seq"
slam_seq_data_new$source = "new scSLAM-seq"

combined = rbind(talk_seq_data, talk_seq_data_TC_intron, slam_seq_data, slam_seq_data_new)

combined$source <- factor(combined$source, levels = c('Talk-seq', 'intronic TC Talk-seq', 'scSLAM-seq', 'new scSLAM-seq'))

comparisons = list(c("MYC_signature - Talk-seq", "Other - Talk-seq"), 
                   c("MYC_signature - intronic TC Talk-seq", "Other - intronic TC Talk-seq"), 
                   c("MYC_signature - scSLAM-seq", "Other - scSLAM-seq"), 
                   c("MYC_signature - new scSLAM-seq", "Other - new scSLAM-seq"))



combined$MYC_signature <- factor(combined$MYC_signature, levels = c("Other", "MYC_signature"))

counts <- combined %>%
  group_by(source, MYC_signature) %>%  
  reframe(n = n()) %>%
  group_by(source) %>% 
  summarise(n = paste("n=", paste(n, collapse = ", ")))



library(ggpp)


plot = ggplot() +
  # geom_jitter(data = combined,#[combined$MYC_signature == "MYC_signature", ], 
  #             aes(x = source, y = log2FoldChange, color = MYC_signature), 
  #             alpha = 0.05,
  #             size = 0.3,
  #             #position = position_jitternudge(width = 0.1, x = 0.19, nudge.from = "jittered")) +
  #             position = position_jitterdodge(jitter.width = 0.4)) +
  geom_boxplot(data = combined, aes(x = source, y = log2FoldChange, color = MYC_signature), outliers = T,
               ) +
  scale_color_manual(values = c("Other" = "deepskyblue3", "MYC_signature" = "red")) +
  labs(#title = "LFC MYC signature vs. Other for Different Data Sources",
       x = NULL,
       y = "-log2(Fold Change MYC vs. MYC Depletion)",
       fill = "Gene Category",
       color = "Gene Category") +
  
  stat_compare_means(data = combined,
                     aes(x = source, y = log2FoldChange, group = MYC_signature),
                     label = "p.signif", 
                     method = "wilcox.test",
                     label.y = 4.5
  )+
  geom_text(
    data = counts,
    aes(x = source, y = -3, label = n),
    size = 4,
    position = position_dodge(width = 0.7)
  ) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme(plot.title = element_text(hjust = 0.5)) +
  scale_y_continuous(breaks = seq(-5, 5, 1))
plot
ggsave("./boxplot_LFC_MYC_signature_vs_Other.pdf", plot, width = 9, height = 6)








talk_seq_data_TC = readRDS("./resources/processed_featureCounts_TC_data.rds")
slam_seq_data_new = readRDS("./resources/processed_grandR_single_cell_new_data.rds")

talk_seq_data_TC = talk_seq_data_TC[, c("gene_id", "log2FoldChange", "MYC_signature")]
slam_seq_data_new = slam_seq_data_new[, c("gene_id", "log2FoldChange")]

names(talk_seq_data_TC)[names(talk_seq_data_TC) == "log2FoldChange"] = "LFC_talk"
names(slam_seq_data_new)[names(slam_seq_data_new) == "log2FoldChange"] = "LFC_slam"

merged = merge(talk_seq_data_TC, slam_seq_data_new, by = "gene_id")

max_abs_value = max(max(abs(merged$LFC_talk)), max(abs(merged$LFC_slam)))

library(grandR)
library(ggplot2)
library(ggnewscale)

merged$density = density2d(merged$LFC_slam, merged$LFC_talk)


plot = ggplot(merged, aes(x = LFC_slam, y = LFC_talk)) +
  geom_point(data=merged[merged$MYC_signature != "MYC_signature", ], aes(color = density), size = 1) +
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density", guide = "none") +
  new_scale_color() +
  geom_point(data=merged[merged$MYC_signature == "MYC_signature", ], aes(color = "MYC_signature"), size = 1) +
  scale_color_manual(values = c("MYC_signature" = "red"), name = "", guide = "none") +
  geom_smooth(method = "lm", color = "blue", se = FALSE) + # 'lm' for a linear model
  geom_smooth(data=merged[merged$MYC_signature == "MYC_signature", ],method = "lm", color = "red", se = FALSE) + # 'lm' for a linear model
  geom_abline(slope = 1, intercept = 0, color = "black", linetype = "dashed") +
  xlim(-max_abs_value - 0.2, max_abs_value + 0.2) +
  ylim(-max_abs_value - 0.2, max_abs_value + 0.2) +
  
  # Fix the aspect ratio to ensure equal scaling
  coord_fixed(ratio = 1) +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  labs(#title = "LFC comparison between TC Talk-seq vs new scSLAM-seq data",
       x = "-log2(Fold Change MYC vs. MYC Depletion) new scSLAM-seq", 
       y = "-log2(Fold Change MYC vs. MYC Depletion) TC Talk-seq")
plot
ggsave("./LFC_comparison_TC_Talk_vs_new_SLAM.pdf", plot, width = 9, height = 9)

