# SPDX-FileCopyrightText: 2025 Julius Deynet <julius.deynet@stud-mail.uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

data = as.data.frame(read.delim("./resources/annotated_peaks_hg38_right.tsv"))
filtered_data = as.data.frame(read.delim("./resources/annotated_peaks_hg38_right_top10.tsv"))



lfc_sc_data = readRDS("./resources/processed_grandR_single_cell_new_data.rds")
lfc_data = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")

create_figures = function(lfc_data, peak_data, lfc_data_name, peak_data_name, fill_color) {
  library(dplyr)
  library(tidyr)
  library(ggplot2)
  
  lfc_data$logPadj_capped = pmin(lfc_data$logPadj, 100)
  
  gene_counts = table(peak_data$gene_id)
  
  lfc_data$peak_count_with_na = as.numeric(gene_counts[match(lfc_data$gene_id, names(gene_counts))])
  
  lfc_data$peak_count = as.numeric(gene_counts[match(lfc_data$gene_id, names(gene_counts))])
  lfc_data$peak_count[is.na(lfc_data$peak_count)] = 0
  
  lfc_data$peak_category <- ifelse(lfc_data$peak_count == 0, "no peak", "1+ peaks")
  
  toUse = lfc_data
  
  toUse = toUse %>% distinct(gene_id, .keep_all = TRUE)
  
  library(dplyr)
  library(tidyr)
  
  # Define the thresholds
  logPadj_threshold <- 1.3
  log2FoldChange_threshold <- 1
  
  # Count genes in each region
  counts <- toUse %>% mutate(
    region = case_when(
      logPadj_capped >= logPadj_threshold & log2FoldChange >= log2FoldChange_threshold ~ "Upper Right",
      logPadj_capped >= logPadj_threshold & log2FoldChange <= -log2FoldChange_threshold ~ "Upper Left",
      logPadj_capped < logPadj_threshold & log2FoldChange >= log2FoldChange_threshold ~ "Lower Right",
      logPadj_capped < logPadj_threshold & log2FoldChange <= -log2FoldChange_threshold ~ "Lower Left",
      TRUE ~ "Other"
    )
  ) %>%
    group_by(region, peak_category) %>%
    summarize(count = n(), .groups = "drop") %>%
    complete(region = c("Upper Right", "Upper Left", "Lower Right", "Lower Left"), 
             peak_category = c("no peak", "1+ peaks"), 
             fill = list(count = 0))
  
  x_range <- range(toUse$log2FoldChange, na.rm = TRUE)
  y_range <- range(toUse$logPadj_capped, na.rm = TRUE)
  
  library(ggnewscale)
  
  p1 = ggplot(toUse, aes(x = log2FoldChange, y = logPadj_capped)) +
    geom_point(data = toUse[is.na(toUse$peak_count_with_na), ],size = 2.5, aes(color = "No Assigned Peak")) +
    scale_color_manual(values = c("No Assigned Peak" = "grey"), name = "") +
    new_scale_color() +
    geom_point(data = toUse[!is.na(toUse$peak_count_with_na), ],size = 2.5, aes(color = peak_count_with_na)) +
    
    geom_hline(yintercept = logPadj_threshold, linetype = "dashed", color = "blue") +
    geom_vline(xintercept = c(-log2FoldChange_threshold, log2FoldChange_threshold), 
               linetype = "dashed", color = "blue") +
    theme_minimal() +
    labs(x = "-log2(Fold Change MYC vs. MYC Depletion)", y = "-log10(p-adj) (capped at 100)", 
         title = paste(peak_data_name, "MYC Binding Sites for", lfc_data_name, "data")) +
    #center title
    theme(plot.title = element_text(hjust = 0.5)) +
    scale_color_gradient(low = "tomato1", high = "red4", name = "Number of Peaks") +
    
    coord_cartesian(xlim = c(x_range[1] - 0.7, x_range[2] + 1), 
                    ylim = c(y_range[1] - 1, y_range[2] + 1)) +
    
    # Add corner annotations
    annotate("text", x = x_range[2] +0.1, y = y_range[2] + 0.5, 
             label = paste("Upper Right\n1+ Peaks:", counts$count[counts$region == "Upper Right" & counts$peak_category == "1+ peaks"],
                           "\nNo Peaks:", counts$count[counts$region == "Upper Right" & counts$peak_category == "no peak"]),
             color = "black", size = 3, hjust = 0) +
    
    annotate("text", x = x_range[1] -0.7, y = y_range[2] + 0.5, 
             label = paste("Upper Left\n1+ Peaks:", counts$count[counts$region == "Upper Left" & counts$peak_category == "1+ peaks"],
                           "\nNo Peaks:", counts$count[counts$region == "Upper Left" & counts$peak_category == "no peak"]),
             color = "black", size = 3, hjust = 0) +
    
    annotate("text", x = x_range[2] + 0.1, y = y_range[1] , 
             label = paste("Lower Right\n1+ Peaks:", counts$count[counts$region == "Lower Right" & counts$peak_category == "1+ peaks"],
                           "\nNo Peaks:", counts$count[counts$region == "Lower Right" & counts$peak_category == "no peak"]),
             color = "black", size = 3, hjust = 0) +
    
    annotate("text", x = x_range[1] -0.7, y = y_range[1] , 
             label = paste("Lower Left\n1+ Peaks:", counts$count[counts$region == "Lower Left" & counts$peak_category == "1+ peaks"],
                           "\nNo Peaks:", counts$count[counts$region == "Lower Left" & counts$peak_category == "no peak"]),
             color = "black", size = 3, hjust = 0)
  
  
  library(dplyr)
  # Rename categories
  toUse = toUse %>%
    mutate(peak_category = ifelse(peak_category == "no peak", "No Peaks", "1+ Peaks"))
  
  toUse$peak_category <- factor(toUse$peak_category, levels = c("No Peaks", "1+ Peaks"))
  
  counts <- toUse %>%
    group_by(peak_category) %>%
    summarise(n = paste("n=", n(), sep = ""))
  
  library(ggpubr)
  
  y_min = min(toUse$log2FoldChange, na.rm = TRUE)
  
  p2 = ggplot(toUse, aes(x = peak_category, y = log2FoldChange)) +
    geom_boxplot(fill = fill_color) +
    labs(x = "Peak Category", y = "-log2(Fold Change MYC vs. MYC Depletion)") +
    ggtitle(paste(peak_data_name, "MYC Binding Sites for", lfc_data_name, "data")) +
    theme_minimal() +
    theme(plot.title = element_text(hjust = 0.5)) +
    
    # Add counts as text labels
    geom_text(
      data = counts,  # Use counts summarised above
      aes(x = peak_category, y = y_min - 0.5, label = n),  # Place text above the boxes
      size = 4
    ) +
    
    theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", linewidth = 1),) +
    stat_compare_means(method = "wilcox.test", label = "p.signif", comparisons = list(c("No Peaks", "1+ Peaks")), hide.ns = FALSE) +
    scale_y_continuous(breaks = seq(-4, 4, 1))
  
  
  
  correlation1 <- cor(as.numeric(toUse$peak_count), toUse$log2FoldChange, method = "pearson", use = "pairwise.complete.obs")
  correlation2 <- cor(as.numeric(toUse$peak_count), toUse$log2FoldChange, method = "spearman", use = "pairwise.complete.obs")
  
  
  category_levels <- c("0", "1", "2", "3", "4+")
  
  # ensure category has string type
  toUse$peak_count <- factor(ifelse(toUse$peak_count >= 4, "4+", toUse$peak_count), levels = as.character(category_levels))
  
  counts <- toUse %>%
    group_by(peak_count) %>%
    summarise(n = paste("n=", n(), sep = ""))
  
  sequential_comparisons <- list()
  
  for (i in 1:(length(category_levels) - 1)) {
    sequential_comparisons[[i]] <- c(as.character(category_levels[i]), as.character(category_levels[i + 1]))
  }
  
  library(ggpubr)
  
  y_min = min(toUse$log2FoldChange, na.rm = TRUE)
  y_max = max(toUse$log2FoldChange, na.rm = TRUE)
  
  # create the right number of positions
  p_val_pos = rep(y_max + 0.5, length(sequential_comparisons)) 
  
  p3 = ggplot(toUse, aes(x = peak_count, group = peak_count, y = log2FoldChange)) +
    geom_boxplot(fill = fill_color) +
    labs(x = "Number of Peaks", y = "-log2(Fold Change MYC vs. MYC Depletion)") +
    ggtitle(paste(peak_data_name, "MYC Binding Sites for", lfc_data_name, "data")) +
    theme_minimal() +
    theme(plot.title = element_text(hjust = 0.1)) +
    
    # Add counts as text labels
    geom_text(
      data = counts,  # Use counts summarised above
      aes(x = peak_count, y = y_min - 0.5, label = n),  # Place text above the boxes
      size = 4
    ) +
    annotate("text", x = 1, y = y_max + 1.5, 
             label = paste0("r = ", round(correlation1, 2), ", p = ", round(correlation2, 2)), 
             hjust = 0, vjust = 0, size = 5, color = "blue") +
    
    theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", linewidth = 1),) +
    stat_compare_means(method = "wilcox.test", label = "p.signif", comparisons = sequential_comparisons, hide.ns = FALSE, label.y = p_val_pos) +
    scale_y_continuous(breaks = seq(-4, 4, 1)) + 
    theme( plot.title = element_text(hjust = 0.5)) 
  
  
  list(p1, p2, p3)
}

plots = create_figures(lfc_data, data, "intronic TC Talk-seq", "All", alpha("lightblue", 0.7))
ggsave("./box_existence_peaks_intronic_TC_talk.svg", plots[[2]], width = 9, height = 6)
ggsave("./box_number_peaks_intronic_TC_talk.pdf", plots[[3]], width = 9, height = 6)
plots = create_figures(lfc_sc_data, data, "new scSLAM-seq", "All", alpha("lightblue", 0.7))
ggsave("./box_existence_peaks_new_slam.svg", plots[[2]], width = 9, height = 6)
ggsave("./box_number_peaks_new_slam.pdf", plots[[3]], width = 9, height = 6)

plots = create_figures(lfc_data, filtered_data, "intronic TC Talk-seq", "Top 10%", alpha("deepskyblue3", 0.5))
ggsave("./box_existence_peaks_intronic_TC_talk_top10.svg", plots[[2]], width = 9, height = 6)
ggsave("./box_number_peaks_intronic_TC_talk_top10.pdf", plots[[3]], width = 9, height = 6)
plots = create_figures(lfc_sc_data, filtered_data, "new scSLAM-seq", "Top 10%", alpha("deepskyblue3", 0.5))
ggsave("./box_existence_peaks_new_slam_top10.svg", plots[[2]], width = 9, height = 6)
ggsave("./box_number_peaks_new_slam_top10.pdf", plots[[3]], width = 9, height = 6)





library(ReactomePA)

gene <- seq2gene(gr_filtered_peaks, tssRegion = c(-3000, 3000), flankDistance = 3000, TxDb=txdb)
pathway2 <- enrichPathway(gene)
head(pathway2, 2)

dotplot(pathway2)


peak_data = as.data.frame(read.delim("./JH477_myc_peaks.tsv"))

comparison_data = merge(merged, peak_data, by = "peak_id")

comparison_data = comparison_data[, c("peak_id", "gene_id", "ensembl_gene_id")]


percentage_matching <- mean(comparison_data$gene_id == comparison_data$ensembl_gene_id, na.rm = TRUE) * 100

# Print the result
percentage_matching

filtered_signatures = subset(merged, significance == "Significant" & log2FoldChange >= 1 & MYC_signature == "MYC_signature")




library(ChIPseeker)
library(TxDb.Hsapiens.UCSC.hg38.knownGene)
library(TxDb.Hsapiens.UCSC.hg19.knownGene)
library(org.Hs.eg.db)

library(GenomicRanges)

chipseq_data = as.data.frame(read.delim("./JH477_myc_peaks.tsv"))

peak_width = chipseq_data$peak_end - chipseq_data$peak_start

chipseq_data$peak_start = chipseq_data$peak_start + peak_width / 2
chipseq_data$peak_end = chipseq_data$peak_start + 1

chipseq_data = chipseq_data[, c("peak_chr", "peak_start", "peak_end", "peak_id", "peak_score", "number_of_cacgtg_eboxes", "number_of_cacntg_eboxes", "coverage_myc")]

chipseq_data = unique(chipseq_data)

# Load transcript database
txdb <- TxDb.Hsapiens.UCSC.hg19.knownGene

# Create GRanges object from the data
gr_peaks <- GRanges(
  seqnames = chipseq_data$peak_chr,  # Chromosome
  ranges = IRanges(
    start = chipseq_data$peak_start, # Start position
    end = chipseq_data$peak_end      # End position
  ),
  peak_id = chipseq_data$peak_id,    # Peak ID (optional metadata)
  peak_score = chipseq_data$peak_score,  # Peak score (optional metadata)
  number_of_cacgtg_eboxes = chipseq_data$number_of_cacgtg_eboxes,
  number_of_cacntg_eboxes = chipseq_data$number_of_cacntg_eboxes,
  coverage_myc = chipseq_data$coverage_myc # Coverage (optional metadata)
)

# Annotate peaks
peakAnno <- annotatePeak(
  gr_peaks,
  TxDb = txdb,
  tssRegion = c(-3000, 3000), # Define TSS region (e.g., ±2kb)
  annoDb = "org.Hs.eg.db"     # Gene annotation database
)

data = as.data.frame(peakAnno)

data = as.data.frame(read.delim("./resources/annotated_peaks.tsv"))

annotated_peaks = as.data.frame(read.delim("./resources/annotated_peaks.tsv"))
chipseq_data = as.data.frame(read.delim("./JH477_myc_peaks.tsv"))

p1 = data[, c("peak_id", "ENSEMBL", "distanceToTSS")]
p2 = annotated_peaks[, c("peak_id", "gene_id", "distanceToTSS")]
p3 = chipseq_data[, c("peak_id", "ensembl_gene_id")]

merged1 = merge(p1, p2, by = "peak_id")
merged2 = merge(p1, p3, by = "peak_id")

mean(merged1$ENSEMBL == merged1$gene_id, na.rm = TRUE) * 100
mean(merged2$ENSEMBL == merged2$ensembl_gene_id, na.rm = TRUE) * 100


calc_perc_1kb = function(percentile) {
  
  percentile = percentile / 100
  
  top_n = quantile(data$coverage_myc, percentile)
  
  data = data[data$coverage_myc >= top_n, ]
  
  # percentage in <= 1kb
  sum(abs(data$distanceToTSS) <= 1000) / nrow(data) * 100
}

# calc percentage in <= 1kb for top 0-99 percentile of coverage MYC
df_peak_score = data.frame(percentile = 0:99, percentage_peak_score = sapply(0:99, calc_perc_1kb))
df_coverage_myc = data.frame(percentile = 0:99, percentage_coverage_myc = sapply(0:99, calc_perc_1kb))

# arg max
df_coverage_myc[which.max(df_coverage_myc$percentage_coverage_myc), ]

combined = merge(df_peak_score, df_coverage_myc, by = "percentile")

# where overlap the curves
combined[which(combined$percentage_peak_score >= combined$percentage_coverage_myc), ]



ggplot(combined, aes(x = percentile)) +
  geom_line(aes(y = percentage_peak_score, color = "peak_score")) +
  geom_line(aes(y = percentage_coverage_myc, color = "coverage_MYC")) +
  labs(
    x = "Top n-th percentile",
    y = "Percentage of assigned peaks in ±1kb of TSS",
    color = "Filtering Parameter"
  ) +
  ggtitle("Percentage of assigned peaks in ±1kb of TSS for top n-th percentile") +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  scale_y_continuous(labels = scales::percent_format(scale = 1)) +
  scale_x_continuous(breaks = seq(0, 100, 10))


ggplot(df, aes(x = percentile, y = percentage)) +
  geom_line() +
  labs(x = "Top n-th percentile of coverage_myc", y = "Percentage of assigned peaks in ±1kb of TSS") +
  ggtitle("Percentage of assigned peaks in ±1kb of TSS for top n-th percentile of coverage_myc") +
  theme_minimal() +
  # line at x = 90
  geom_vline(xintercept = 90, linetype = "dashed", color = "red") 


lfc_sc_data = readRDS("./resources/processed_grandR_single_cell_new_data.rds")
lfc_data = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")



calc_percentiles = function(lfc_data, title) {
  
  lfc_for_peaks_peak_score = function(percentile) {
    
    percentile = percentile / 100
    
    top_n = quantile(data$peak_score, percentile)
    
    data = data[data$peak_score >= top_n, ]
    
    lfc = lfc_data[lfc_data$gene_id %in% data$gene_id, ]
    
    mean(lfc$log2FoldChange, na.rm = TRUE)
  }
  lfc_for_peaks_coverage_myc = function(percentile) {
    
    percentile = percentile / 100
    
    top_n = quantile(data$coverage_myc, percentile)
    
    data = data[data$coverage_myc >= top_n, ]
    
    lfc = lfc_data[lfc_data$gene_id %in% data$gene_id, ]
    
    mean(lfc$log2FoldChange, na.rm = TRUE)
  }
  lfc_for_peaks_coverage_myc_ratio = function(percentile) {
    
    percentile = percentile / 100
    
    top_n = quantile(data$coverage_myc_ratio, percentile)
    
    data = data[data$coverage_myc_ratio >= top_n, ]
    
    lfc = lfc_data[lfc_data$gene_id %in% data$gene_id, ]
    
    mean(lfc$log2FoldChange, na.rm = TRUE)
  }
  
  lfc_for_peaks_near = function(percentile) {
    
    percentile = percentile / 100
    
    top_n = -quantile(-abs(data$distanceToTSS), percentile)
    
    data = data[abs(data$distanceToTSS) <= top_n, ]
    
    lfc = lfc_data[lfc_data$gene_id %in% data$gene_id, ]
    
    mean(lfc$log2FoldChange, na.rm = TRUE)
  }
  
  df_lfc_peak_score = data.frame(percentile = 0:99, lfc_for_peaks_peak_score = sapply(0:99, lfc_for_peaks_peak_score))
  df_lfc_coverage_myc = data.frame(percentile = 0:99, lfc_for_peaks_coverage_myc = sapply(0:99, lfc_for_peaks_coverage_myc))
  df_lfc_coverage_myc_ratio = data.frame(percentile = 0:99, lfc_for_peaks_coverage_myc_ratio = sapply(0:99, lfc_for_peaks_coverage_myc_ratio))
  df_lfc_coverage_myc_near = data.frame(percentile = 0:99, lfc_coverage_myc_near = sapply(0:99, lfc_for_peaks_near))
  
  # arg max
  #df_coverage_myc[which.max(df_coverage_myc$percentage_coverage_myc), ]
  
  combined_lfc = merge(df_lfc_peak_score, df_lfc_coverage_myc, by = "percentile")
  combined_lfc = merge(combined_lfc, df_lfc_coverage_myc_ratio, by = "percentile")
  combined_lfc = merge(combined_lfc, df_lfc_coverage_myc_near, by = "percentile")
  
  print(subset(combined_lfc, percentile == 90))
  
  library(RColorBrewer)
  
  colors = brewer.pal(n = 4, name = "Dark2")
  colors[3] = "skyblue"
  
  ggplot(combined_lfc, aes(x = percentile)) +
    geom_line(aes(y = lfc_for_peaks_peak_score, color = "peak_score")) +
    geom_line(aes(y = lfc_for_peaks_coverage_myc, color = "coverage_MYC")) +
    geom_line(aes(y = lfc_for_peaks_coverage_myc_ratio, color = "coverage_MYC Ratio")) +
    geom_line(aes(y = lfc_coverage_myc_near, color = "Dist To TSS")) +
    scale_color_manual(values = colors) +
    labs(x = "Top n-th percentile", y = "-log2(Fold Change MYC vs MYC Depletion)", color = "Filtering Parameter") +
    ggtitle(title) +
    theme_minimal() +
    theme(plot.title = element_text(hjust = 0.5)) +
    theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
    scale_x_continuous(breaks = seq(0, 100, 10))
}

plot = calc_percentiles(lfc_data, "intronic TC Talk-seq")
plot
ggsave("./percentile_talk.pdf", plot, width = 9, height = 6)
plot = calc_percentiles(lfc_sc_data, "new scSLAM-seq")
plot
ggsave("./percentile_slam.pdf", plot, width = 9, height = 6)


filtered_peaks <- data[data$distanceToTSS >= -3000 & data$distanceToTSS <= 3000, ]


plot = ggplot(data, aes(x = distanceToTSS)) +
  geom_density(, fill = "skyblue", alpha = 0.7) +
  labs(#title = "Density for Distance to TSS for ChIP-seq peaks", 
    x = "Distance to TSS", 
    y = "Density") +
  theme_minimal() +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  scale_x_continuous(breaks = seq(-3000, 3000, 1000)) +
  annotate(
    "segment",
    x = -3000, xend = 3000,  # Adjust start and end positions as needed
    y = -0.00005, yend = -0.00005,  # Adjust y position
    arrow = arrow(length = unit(0.2, "inches")),
    color = "black",
    size = 0.5
  )

plot
ggsave("./distanceToTSS.pdf", plot, width = 9, height = 4)
