# SPDX-FileCopyrightText: 2025 Julius Deynet <julius.deynet@stud-mail.uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

promoter_coverages = as.data.frame(read.delim("./resources/promoter_coverages_hg_38.tsv"))

lfc_data = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")

merged = merge(lfc_data, promoter_coverages, by="gene_id")

signature = subset(merged, MYC_signature == "MYC_signature")

mean(signature$coverage_myc_upstream) / mean(merged$coverage_myc_upstream)
mean(signature$coverage_myc_downstream) / mean(merged$coverage_myc_downstream)



merged$density = density2d(merged$log2FoldChange, merged$coverage_myc_upstream)

correlation1 = cor(merged$coverage_myc_upstream, merged$log2FoldChange, method="pearson")
correlation2 = cor(merged$coverage_myc_upstream, merged$log2FoldChange, method="spearman")

plot = ggplot(merged, aes(x=log2FoldChange, y=coverage_myc_upstream))+ 
  geom_point(aes(color = density), size = 0.5) +
  theme_minimal() + 
  geom_smooth(method="lm") + 
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color()+
  geom_point(data = merged[merged$MYC_signature == "MYC_signature" ,], aes(color = "MYC_signature"), size = 0.5) +
  geom_smooth(data = merged[merged$MYC_signature == "MYC_signature" ,], method="lm", color = "red") + 
  scale_color_manual(values = c("MYC_signature" = "red"), labels = c("MYC Signature")) +
  guides(color = guide_legend(order = 1), 
         fill = guide_colorbar(order = 2)) +
  geom_vline(xintercept = c(-1, 1), 
             linetype = "dashed", color = "blue") +
  annotate("text", x = -3.6, y = 500, 
           label = paste0("r = ", round(correlation1, 2), ", p = ", round(correlation2, 2), "\nn = ", nrow(merged)), 
           hjust = 0, vjust = 1.1, size = 4, color = "black") + 
  labs(x = "-log2(Fold Change MYC vs. MYC Depletion)", 
       y = " 2000bp Upstream Promoter MYC Coverage", 
       title = "Upstream Promoter MYC Coverage",
       color = "") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5))
plot
ggsave("./scatter_upstream_coverage_vs_lfc.pdf", plot, width = 9, height = 6)


merged$density = density2d(merged$log2FoldChange, merged$coverage_myc_downstream)

correlation1 = cor(merged$coverage_myc_downstream, merged$log2FoldChange, method="pearson")
correlation2 = cor(merged$coverage_myc_downstream, merged$log2FoldChange, method="spearman")

plot = ggplot(merged, aes(x=log2FoldChange, y=coverage_myc_downstream))+ 
  geom_point(aes(color = density), size = 0.5) + theme_minimal() + geom_smooth(method="lm") + 
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color()+
  geom_point(data = merged[merged$MYC_signature == "MYC_signature" ,], aes(color = "MYC_signature"), size = 0.5) +
  geom_smooth(data = merged[merged$MYC_signature == "MYC_signature" ,], method="lm", color = "red") + 
  scale_color_manual(values = c("MYC_signature" = "red"), labels = c("MYC Signature")) +
  guides(color = guide_legend(order = 1), 
         fill = guide_colorbar(order = 2)) +
  geom_vline(xintercept = c(-1, 1), 
             linetype = "dashed", color = "blue") +
  annotate("text", x = -3.6, y = 500, 
           label = paste0("r = ", round(correlation1, 2), ", p = ", round(correlation2, 2), "\nn = ", nrow(merged)), 
           hjust = 0, vjust = 1.1, size = 4, color = "black") + 
  labs(x = "-log2(Fold Change MYC vs. MYC Depletion)", 
       y = " 2000bp Downstream Promoter MYC Coverage", 
       title = "Downstream Promoter MYC Coverage",
       color = "") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5))
plot
ggsave("./scatter_downstream_coverage_vs_lfc.pdf", plot, width = 9, height = 6)
  


merged$density = density2d(merged$log2FoldChange, merged$coverage_myc)

correlation1 = cor(merged$coverage_myc, merged$log2FoldChange, method="pearson")
correlation2 = cor(merged$coverage_myc, merged$log2FoldChange, method="spearman")

plot = ggplot(merged, aes(x=log2FoldChange, y=coverage_myc))+ 
  geom_point(aes(color = density), size = 0.5) + theme_minimal() + geom_smooth(method="lm") + 
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color()+
  geom_point(data = merged[merged$MYC_signature == "MYC_signature" ,], aes(color = "MYC_signature"), size = 0.5) +
  geom_smooth(data = merged[merged$MYC_signature == "MYC_signature" ,], method="lm", color = "red") + 
  scale_color_manual(values = c("MYC_signature" = "red")) +
  guides(color = guide_legend(order = 1), 
         fill = guide_colorbar(order = 2)) +
  geom_vline(xintercept = c(-1, 1), 
             linetype = "dashed", color = "blue") +
  annotate("text", x = -3.6, y = 750, 
           label = paste0("r = ", round(correlation1, 2), ", p = ", round(correlation2, 2), "\nn = ", nrow(merged)), 
           hjust = 0, vjust = 1.1, size = 4, color = "black") + 
  labs(x = "-log2(Fold Change MYC vs. MYC Depletion)", 
       y = "±2000bp Promoter MYC Coverage", 
       title = "Promoter MYC Coverage",
       color = "") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5))
plot
ggsave("./scatter_promoter_coverage_vs_lfc.pdf", plot, width = 9, height = 6)

mean(merged$coverage_myc)
mean(merged[merged$MYC_signature == "MYC_signature",]$coverage_myc)

mean(merged$coverage_myc_upstream)
mean(merged[merged$MYC_signature == "MYC_signature",]$coverage_myc_upstream)

mean(merged$coverage_myc_downstream)
mean(merged[merged$MYC_signature == "MYC_signature",]$coverage_myc_downstream)

annotated_peaks = as.data.frame(read.delim("./resources/annotated_peaks_hg38_right.tsv"))
lfc_data = readRDS("./resources/processed_featureCounts_introns_TC_data.rds")

merged_peaks = merge(lfc_data, annotated_peaks, by="gene_id")
merged_peaks = merged_peaks %>% group_by(gene_id) %>% filter(is.na(coverage_myc) | max(coverage_myc) == coverage_myc) %>% distinct(gene_id, .keep_all = TRUE) %>% ungroup()

correlation1 = cor(merged_peaks$coverage_myc, merged_peaks$log2FoldChange, method="pearson")
correlation2 = cor(merged_peaks$coverage_myc, merged_peaks$log2FoldChange, method="spearman")

merged_peaks$density = density2d(merged_peaks$log2FoldChange, merged_peaks$coverage_myc)

plot = ggplot(merged_peaks, aes(x=log2FoldChange, y=coverage_myc))+ 
  geom_point(aes(color = density), size = 0.5) + theme_minimal() + geom_smooth(method="lm") + 
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color()+
  geom_point(data = merged_peaks[merged_peaks$MYC_signature == "MYC_signature" ,], aes(color = "MYC_signature"), size = 0.5) +
  geom_smooth(data = merged_peaks[merged_peaks$MYC_signature == "MYC_signature" ,], method="lm", color = "red") + 
  scale_color_manual(values = c("MYC_signature" = "red")) +
  guides(color = guide_legend(order = 1), 
         fill = guide_colorbar(order = 2)) +
  geom_vline(xintercept = c(-1, 1), 
             linetype = "dashed", color = "blue") +
  annotate("text", x = -3.6, y = 600, 
           label = paste0("r = ", round(correlation1, 2), ", p = ", round(correlation2, 2), "\nn = ", nrow(merged_peaks)), 
           hjust = 0, vjust = 1.1, size = 4, color = "black") + 
  labs(x = "-log2(Fold Change MYC vs. MYC Depletion)", 
       y = "Strongest Peak MYC Coverage", 
       title = "Strongest Peak MYC Coverage",
       color = "") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5))
plot
ggsave("./scatter_strongest_peak_coverage_vs_lfc.pdf", plot, width = 9, height = 6)


mean(merged_peaks$coverage_myc)
mean(merged_peaks[merged_peaks$MYC_signature == "MYC_signature",]$coverage_myc)

bursting_data = as.data.frame(read.csv("./resources/bursting_all_genes.csv"))
bursting_data = subset(bursting_data, bestmodel != "no change")
names(bursting_data)[names(bursting_data) == "km"] = "burst_frequency"
names(bursting_data)[names(bursting_data) == "B"] = "burst_size"
bursting_data$burst_size = pmax(bursting_data$burst_size, -4)
bursting_data$burst_size = pmin(bursting_data$burst_size, 4)
bursting_data$burst_frequency = pmax(bursting_data$burst_frequency, -4)
bursting_data$burst_frequency = pmin(bursting_data$burst_frequency, 4)
merged_bursting = merge(merged, bursting_data, by.x="gene_name", by.y="gene")
cor(merged_bursting$coverage_myc, merged_bursting$burst_size, method="spearman")
cor(merged_bursting$coverage_myc, merged_bursting$burst_frequency, method="spearman")
cor(merged_bursting$coverage_myc, merged_bursting$burst_frequency + merged_bursting$burst_size, method="spearman")


correlation = cor(merged_bursting$coverage_myc, merged_bursting$burst_size, method="spearman")

merged_bursting$density = density2d(merged_bursting$burst_size, merged_bursting$coverage_myc)

plot = ggplot(merged_bursting, aes(x=burst_size, y=coverage_myc))+ 
  geom_point(aes(color = density), size = 0.5) + theme_minimal() + geom_smooth(method="lm") + 
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color()+
  geom_point(data = merged_bursting[merged_bursting$MYC_signature == "MYC_signature" ,], aes(color = "MYC_signature"), size = 0.5) +
  scale_color_manual(values = c("MYC_signature" = "red")) +
  geom_vline(xintercept = c(-1, 1), 
             linetype = "dashed", color = "blue") +
  annotate("text", x = -4, y = 550, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") + 
  labs(x = "-log2(Fold Change Burst Size MYC vs. MYC Depletion) (capped at -4)", 
       y = "±2000bp Promoter Coverage_MYC", 
       title = "Promoter Coverage_MYC for Burst Size of intronic TC Talk-seq data",
       color = "") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5))
plot
ggsave("./scatter_promoter_coverage_vs_burst_size.svg", plot, width = 9, height = 6)


correlation = cor(merged_bursting$coverage_myc, merged_bursting$burst_frequency, method="spearman")

merged_bursting$density = density2d(merged_bursting$burst_frequency, merged_bursting$coverage_myc)

plot = ggplot(merged_bursting, aes(x=burst_frequency, y=coverage_myc))+ 
  geom_point(aes(color = density), size = 0.5) + theme_minimal() + geom_smooth(method="lm") + 
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color()+
  geom_point(data = merged_bursting[merged_bursting$MYC_signature == "MYC_signature" ,], aes(color = "MYC_signature"), size = 0.5) +
  scale_color_manual(values = c("MYC_signature" = "red")) +
  geom_vline(xintercept = c(-1, 1), 
             linetype = "dashed", color = "blue") +
  annotate("text", x = -2.5, y = 550, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") + 
  labs(x = "-log2(Fold Change Burst Frequency MYC vs. MYC Depletion) (capped at 4)", 
       y = "±2000bp Promoter Coverage_MYC", 
       title = "Promoter Coverage_MYC for Burst Frequency of intronic TC Talk-seq data",
       color = "") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5))
plot
ggsave("./scatter_promoter_coverage_vs_burst_frequency.svg", plot, width = 9, height = 6)


plot_stuff = function(x, y) {

correlation = cor(merged_bursting[[y]], merged_bursting[[x]], method="spearman")

merged_bursting$density = density2d(merged_bursting[[x]], merged_bursting[[y]])

ggplot(merged_bursting, aes(x=!!sym(x), y=!!sym(y)))+ 
  geom_point(aes(color = density), size = 0.5) + theme_minimal() + geom_smooth(method="lm") + 
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color()+
  geom_point(data = merged_bursting[merged_bursting$MYC_signature == "MYC_signature" ,], aes(color = "MYC_signature"), size = 0.5) +
  geom_smooth(data = merged_bursting[merged_bursting$MYC_signature == "MYC_signature" ,], method="lm", color = "red") + 
  scale_color_manual(values = c("MYC_signature" = "red")) +
  geom_vline(xintercept = c(-1, 1), 
             linetype = "dashed", color = "blue") +
  annotate("text", x = -2.5, y = 550, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") + 
  labs(color = "") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5))

}
plot_stuff("burst_size", "coverage_myc_upstream")
plot_stuff("burst_size", "coverage_myc_downstream")
plot_stuff("burst_frequency", "coverage_myc_upstream")
plot_stuff("burst_frequency", "coverage_myc_downstream")


correlation = cor(merged_bursting$coverage_myc, merged_bursting$burst_frequency + merged_bursting$burst_size, method="spearman")

merged_bursting$density = density2d(merged_bursting$burst_frequency + merged_bursting$burst_size, merged_bursting$coverage_myc)

plot = ggplot(merged_bursting, aes(x=burst_frequency + burst_size, y=coverage_myc))+ 
  geom_point(aes(color = density), size = 0.5) + theme_minimal() + geom_smooth(method="lm") + 
  scale_color_gradient(low = "lightblue", high = "darkblue", name = "Density") +
  new_scale_color()+
  geom_point(data = merged_bursting[merged_bursting$MYC_signature == "MYC_signature" ,], aes(color = "MYC_signature"), size = 0.5) +
  scale_color_manual(values = c("MYC_signature" = "red")) +
  geom_vline(xintercept = c(-1, 1), 
             linetype = "dashed", color = "blue") +
  annotate("text", x = -3, y = 550, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") + 
  labs(x = "-log2(Fold Change Burst Size * Frequency MYC vs. MYC Depletion) (capped at 4)", 
       y = "±2000bp Promoter Coverage_MYC", 
       title = "Promoter Coverage_MYC for Burst Frequency + Burst Size of intronic TC Talk-seq data",
       color = "") +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5))
plot
ggsave("./scatter_promoter_coverage_vs_burst_frequency_plus_burst_size.svg", plot, width = 9, height = 6)


correlation = cor(merged$CpG_island_upstream, merged$coverage_myc_upstream, method="spearman")

comparisons <- list(c("FALSE", "TRUE"))

counts <- merged %>%
  group_by(CpG_island_upstream) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(merged, aes(x = CpG_island_upstream, y = coverage_myc_upstream)) + 
  geom_boxplot(outliers = FALSE) + theme_minimal() + 
  labs(title = "Upstream Promoter Coverage_MYC for CpG islands vs non CpG islands",
       x = "CpG island",
       y = " 2000bp Upstream Promoter Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = CpG_island_upstream, y = -25, label = n), # Fixed y position
    size = 4
  )+
  annotate("text", x = 1, y = 105, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5)) +
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = comparisons, hide.ns = FALSE, label.y = 70)
plot
ggsave("./boxplot_upstream_coverage_vs_cpg_island.svg", plot, width = 9, height = 6)



correlation = cor(merged$CpG_island_downstream, merged$coverage_myc_downstream, method="spearman")

comparisons <- list(c("FALSE", "TRUE"))

counts <- merged %>%
  group_by(CpG_island_downstream) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(merged, aes(x = CpG_island_downstream, y = coverage_myc_downstream)) + 
  geom_boxplot(outliers = FALSE) + theme_minimal() + 
  labs(title = "Downstream Promoter Coverage_MYC for CpG islands vs non CpG islands",
       x = "CpG island",
       y = "2000bp Downstream Promoter Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = CpG_island_downstream, y = -25, label = n), # Fixed y position
    size = 4
  )+
  annotate("text", x = 1, y = 130, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5)) +
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = comparisons, hide.ns = FALSE, label.y = 95)
plot
ggsave("./boxplot_downstream_coverage_vs_cpg_island.svg", plot, width = 9, height = 6)


correlation = cor(merged$CpG_island, merged$coverage_myc, method="spearman")

comparisons <- list(c("FALSE", "TRUE"))

counts <- merged %>%
  group_by(CpG_island) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(merged, aes(x = CpG_island, y = coverage_myc)) +
  geom_boxplot(outliers = FALSE) + theme_minimal() + 
  labs(title = "Promoter Coverage_MYC for CpG islands vs non CpG islands",
       x = "CpG island",
       y = "±2000bp Promoter Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = CpG_island, y = -40, label = n), # Fixed y position
    size = 4
  )+
  annotate("text", x = 1, y = 210, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5)) +
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = comparisons, hide.ns = FALSE, label.y = 150)
plot
ggsave("./boxplot_promoter_coverage_vs_cpg_island.svg", plot, width = 9, height = 6)



merged$TATA_upstream_exists = merged$TATA_upstream > 0
merged$TATA_downstream_exists = merged$TATA_downstream > 0
merged$TATA_exists = merged$TATA > 0

correlation = cor(merged$TATA_upstream, merged$coverage_myc_upstream, method="spearman")

comparisons <- list(c("FALSE", "TRUE"))

counts <- merged %>%
  group_by(TATA_upstream_exists) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(merged, aes(x = TATA_upstream_exists, y = coverage_myc_upstream)) + 
  geom_boxplot(outliers = FALSE) + theme_minimal() + 
  labs(title = "Upstream Promoter Coverage_MYC for Existence of TATA-boxes",
       x = "TATA-box exists",
       y = " 2000bp Upstream Promoter Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = TATA_upstream_exists, y = -25, label = n), # Fixed y position
    size = 4
  )+
  annotate("text", x = 1, y = 105, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5)) +
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = comparisons, hide.ns = FALSE, label.y = 70)
plot
ggsave("./boxplot_upstream_coverage_vs_tata.svg", plot, width = 9, height = 6)



correlation = cor(merged$TATA_downstream, merged$coverage_myc_downstream, method="spearman")

comparisons <- list(c("FALSE", "TRUE"))

counts <- merged %>%
  group_by(TATA_downstream_exists) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(merged, aes(x = TATA_downstream_exists, y = coverage_myc_downstream)) + 
  geom_boxplot(outliers = FALSE) + theme_minimal() + 
  labs(title = "Downstream Promoter Coverage_MYC for Existence of TATA-boxes",
       x = "TATA-box exists",
       y = "2000bp Downstream Promoter Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = TATA_downstream_exists, y = -40, label = n), # Fixed y position
    size = 4
  )+
  annotate("text", x = 1, y = 130, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5)) +
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = comparisons, hide.ns = FALSE, label.y = 95)
plot
ggsave("./boxplot_downstream_coverage_vs_tata.svg", plot, width = 9, height = 6)


correlation = cor(merged$TATA, merged$coverage_myc, method="spearman")

comparisons <- list(c("FALSE", "TRUE"))

counts <- merged %>%
  group_by(TATA_exists) %>%
  summarise(n = paste("n=", n(), sep = ""))

plot = ggplot(merged, aes(x = TATA_exists, y = coverage_myc)) +
  geom_boxplot(outliers = FALSE) + theme_minimal() + 
  labs(title = "Promoter Coverage_MYC for Existence of TATA-boxes",
       x = "TATA-box exists",
       y = "±2000bp Promoter Coverage_MYC") +
  geom_text(
    data = counts,
    aes(x = TATA_exists, y = -40, label = n), # Fixed y position
    size = 4
  )+
  annotate("text", x = 1, y = 210, 
           label = paste0("Correlation: ", round(correlation, 2)), 
           hjust = 0, vjust = 1.1, size = 5, color = "blue") +
  theme_minimal()+ 
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),) +
  theme( plot.title = element_text(hjust = 0.5)) +
  stat_compare_means(method="wilcox.test", label = "p.signif", comparisons = comparisons, hide.ns = FALSE, label.y = 150)
plot
ggsave("./boxplot_promoter_coverage_vs_tata.svg", plot, width = 9, height = 6)

