# SPDX-FileCopyrightText: 2025 Julius Deynet <julius.deynet@stud-mail.uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

#awk '$3 == "gene" { 
#    tss = ($7 == "+") ? $4 : $5; 
#    print $1, tss-1, tss, $10, 0, $7 
#}' OFS="\t" homo_sapiens.90.gtf | tr -d '";' > ChIP-seq/peak_calling/output_tss.bed

bedtools sort -i output_tss.bed > output_tss_sorted.bed

# Find the 3 closest TSSs for every MYC peak summit
bedtools closest -k 3 -d -a ../peaks/MYC.DMSO.spikenorm_summits.bed -b output_tss_sorted.bed | \
# Keep peak when it is within TSS ± 3kb
awk 'BEGIN{OFS="\t"} {if (sqrt($12^2) < 3000) print}' | \
# change distance to be relative to TSS
awk 'BEGIN{OFS="\t"} {if (($11 == "+" && $2 < $7)||($11 == "-" && $2 > $7)) print $1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,-$12; else print $1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12;}' | \
# extend peak summit by 250 bp in both directions
bedtools slop -i stdin -g hg38.genome -b 250 | \
# extend peak region further to summit ± 500 bp for read counting
bedtools slop -i stdin -g hg38.genome -b 250 \
> JH477_A375_MYC_promoter_peaks.bed

wc -l JH477_A375_MYC_promoter_peaks.bed # 11,096
head -n 50 JH477_A375_MYC_promoter_peaks.bed # 11,096

# count Input and MYC ChIP-seq reads in 1 kb window around peak summit
bedtools bamtobed -i ../ChIP-seq/bams/MYC.DMSO.bam | bedtools sort -i stdin > temp.bed && bedtools coverage -counts -a JH477_A375_MYC_promoter_peaks.bed -b temp.bed > coverage_JH477_A375_MYC_promoter_peaks_MYC.bed

bedtools bamtobed -i ../ChIP-seq/bams/Input.merged.bam | bedtools sort -i stdin > temp.bed && bedtools coverage -counts -a JH477_A375_MYC_promoter_peaks.bed -b temp.bed > coverage_JH477_A375_MYC_promoter_peaks_Input.bed

# Counts were normalized according to the mouse spike-in and input signal was subtracted from MYC signal in annotate_chip_seq.R.
