# SPDX-FileCopyrightText: 2025 Julius Deynet <julius.deynet@stud-mail.uni-wuerzburg.de>
#
# SPDX-License-Identifier: GPL-3.0-or-later

library(ggplot2)

# Create the data frame
df <- data.frame(
  Feature = c( "All", "MYC Coverage","Peak Score","MYC Coverage Ratio","CACGTG","CACGCG","CpG Island","CATGTG","Distance To TSS","CATGCG","CACGAG","CACATG","Peak Count","TATA" ),
  MAE = c( 0.38297606621577035, 0.3921157931143101,0.39614348337856015,0.4037586646341273,0.4200663834784243,0.42381787525277304,0.4245278543558968,0.42659576818458406,0.4267946980048607,0.4272271759736315,0.4274696130989424,0.4277748772844535,0.42863961653939947,0.42873513232736293 )
)

df <- df %>% arrange(MAE)

# Baseline MAE
baseline_mae <- 0.4316

# Create the plot
plot = ggplot(df, aes(x = reorder(Feature, -MAE, ), y = MAE, fill = MAE < baseline_mae)) +
  geom_bar(stat = "identity") +
  geom_hline(yintercept = baseline_mae, linetype = "dashed", color = "red", linewidth = 1) +
  coord_flip() +  # Flip coordinates for better readability
  labs(#title = "MAE for LFC of Linear Regression Models by Feature",
       x = "Feature",
       y = "Mean Absolute Error (MAE)",
       fill = "Better than Baseline") +
  scale_fill_manual(values = c("TRUE" = alpha("deepskyblue3", 0.7), "FALSE" = "gray")) +
  guides(fill = "none") +
  theme_minimal() +
theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),)
plot
ggsave("./box_mea_lfc_1_feature.pdf", plot, width = 9, height = 6)



# Create the data frame
df <- data.frame(
  Feature = c( "All", "CpG Island","CACGCG","CACGTG","TATA","CATGCG","CACGAG","CATGTG","CACATG" ),
  MAE = c( 0.31184845037727343, 0.3202135481558392,0.4031384000209062,0.404946623858101,0.4107545516377048,0.41414577537124997,0.41416941061857276,0.414223591897541,0.41514591654844224 )
)

df <- df %>% arrange(MAE)

# Baseline MAE
baseline_mae <- 0.4144

# Create the plot
plot = ggplot(df, aes(x = reorder(Feature, -MAE, ), y = MAE, fill = MAE < baseline_mae)) +
  geom_bar(stat = "identity") +
  geom_hline(yintercept = baseline_mae, linetype = "dashed", color = "red", linewidth = 1) +
  coord_flip() +  # Flip coordinates for better readability
  labs(#title = "MAE for log(MYC Coverage) of Linear Regression Models by Feature",
       x = "Feature",
       y = "Mean Absolute Error (MAE)",
       fill = "Better than Baseline") +
  theme_minimal() +
  guides(fill = "none") +
  scale_fill_manual(values = c("TRUE" = alpha("deepskyblue3", 0.7), "FALSE" = "gray")) +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),)
plot
ggsave("./box_mea_coverage_1_feature.pdf", plot, width = 9, height = 6)



# Create a data frame for pairwise MAE values
df_pairs <- data.frame(
  Feature = c( "All", "(CACGTG, MYC Coverage)","(Peak Score, MYC Coverage)","(CACGCG, MYC Coverage)","(MYC Coverage, Distance To TSS)","(CATGCG, MYC Coverage)","(CACATG, MYC Coverage)","(CATGTG, MYC Coverage)","(MYC Coverage, CpG Island)","(CACGAG, MYC Coverage)","(MYC Coverage, peak_count)","(TATA, MYC Coverage)","(MYC Coverage, MYC Coverage Ratio)","(CACGCG, Peak Score)","(CACGTG, Peak Score)","(Peak Score, MYC Coverage Ratio)","(Peak Score, CpG Island)","(Peak Score, Distance To TSS)","(CATGCG, Peak Score)","(CATGTG, Peak Score)","(CACATG, Peak Score)","(CACGAG, Peak Score)","(Peak Score, peak_count)","(TATA, Peak Score)","(CACGTG, MYC Coverage Ratio)","(CACGCG, MYC Coverage Ratio)","(MYC Coverage Ratio, CpG Island)","(CATGCG, MYC Coverage Ratio)","(MYC Coverage Ratio, Distance To TSS)","(CATGTG, MYC Coverage Ratio)","(CACATG, MYC Coverage Ratio)","(CACGAG, MYC Coverage Ratio)","(MYC Coverage Ratio, peak_count)","(TATA, MYC Coverage Ratio)","(CACGTG, CACGCG)","(CACGTG, CpG Island)","(CACGTG, Distance To TSS)","(CACGTG, CATGTG)","(CACGTG, CATGCG)","(CACGTG, CACGAG)","(CACGTG, CACATG)","(CACGTG, peak_count)","(CACGTG, TATA)","(CACGCG, CpG Island)","(CACGCG, CATGTG)","(CACGCG, Distance To TSS)","(CATGTG, CpG Island)","(CACGCG, CACGAG)","(CACGCG, CATGCG)","(CACGCG, CACATG)","(Distance To TSS, CpG Island)","(CACATG, CpG Island)","(CACGAG, CpG Island)","(CATGCG, CpG Island)","(CACGCG, peak_count)","(CACGCG, TATA)","(peak_count, CpG Island)","(TATA, CpG Island)","(CATGTG, Distance To TSS)","(CATGCG, CATGTG)","(CATGTG, CACGAG)","(CATGCG, Distance To TSS)","(CACGAG, Distance To TSS)","(CACATG, Distance To TSS)","(CATGCG, CACGAG)","(CATGTG, CACATG)","(CATGCG, CACATG)","(CATGTG, peak_count)","(CACGAG, CACATG)","(Distance To TSS, peak_count)","(CATGTG, TATA)","(TATA, Distance To TSS)","(CATGCG, peak_count)","(CACGAG, peak_count)","(CATGCG, TATA)","(CACATG, peak_count)","(CACGAG, TATA)","(CACATG, TATA)","(TATA, peak_count)" ),
  MAE = c( 0.38297606621577035, 0.3898461187059631,0.3903680909991554,0.39067987504166757,0.39077379270937324,0.391057352133128,0.3913307662884107,0.39135085745247894,0.3914031274357447,0.3916405595492656,0.3920092740294808,0.39222860819790745,0.39229838177992515,0.39364218093945263,0.3941767045053673,0.3944939579479224,0.3946200102808341,0.39464875104066127,0.39482336220241493,0.39512758753062704,0.3955362811444301,0.39565429224301535,0.39614898105813345,0.39630373848502753,0.40025904450083305,0.4011745271333138,0.4018005268458117,0.402010206110863,0.40231094066851897,0.4024392763631351,0.4027806020710733,0.40310683251702906,0.4038107837481543,0.4038929764870155,0.41544135284403905,0.4168690732305827,0.4183799271923049,0.41851162953266025,0.418644409339633,0.4189342374206522,0.4192204185056042,0.4203942752085401,0.42044928221599526,0.4207375661481944,0.4218381201151024,0.42216216237267334,0.4222231856657577,0.4226447988417812,0.4227356428359699,0.42290387267062085,0.42311882528381595,0.4231502527563858,0.4235892139082398,0.4236220005884996,0.424055500495215,0.42418122725997004,0.4247042114693547,0.42481250823062533,0.42500869486720416,0.42535616390297964,0.4255248848433965,0.4255693756714823,0.42561676467767967,0.4259597968564009,0.42616626644085087,0.42623089301974176,0.42677355000441725,0.42677647132897695,0.4267915959940179,0.426898377359923,0.42690294100573783,0.4270305437980685,0.42733577791127964,0.4275409992007992,0.42755274907016627,0.42777816020649906,0.4278059866252904,0.42810518718926366,0.4289705651948582 )
)

# Define the baseline MAE
baseline_mae <- 0.4316
library(dplyr)
df_pairs = df_pairs %>% head(15) %>% rbind(df_pairs %>% tail(5))

# Plot the MAE for pairs of features
plot = ggplot(df_pairs, aes(x = reorder(Feature, -MAE), y = MAE, fill = MAE < baseline_mae)) +
  geom_bar(stat = "identity") +
  geom_hline(yintercept = baseline_mae, linetype = "dashed", color = "red", linewidth = 1) +
  coord_flip() +  # Flip coordinates for better readability
  labs(#title = "Pairwise MAE for LFC of Linear Regression Models by Features (top 15 and bottom 5)",
       x = "Feature Pair",
       y = "Mean Absolute Error (MAE)",
       fill = "Better than Baseline") +
  scale_fill_manual(values = c("TRUE" = alpha("deepskyblue3", 0.7), "FALSE" = "gray")) +
  theme_minimal() +
  guides(fill = "none") +
  theme(plot.title = element_text(hjust = 0.5)) +
  theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),)
plot
ggsave("./box_mea_lfc_2_feature.pdf", plot, width = 9, height = 6)



# Create a data frame for pairwise MAE values
df_pairs <- data.frame(
  Feature = c( "All", "CpG Island", "(CACGTG, CpG Island)","(CACGCG, CpG Island)","(TATA, CpG Island)","(CACGAG, CpG Island)","(CATGCG, CpG Island)","(CACATG, CpG Island)","(CATGTG, CpG Island)","(CACGTG, CACGCG)","(CACGCG, TATA)","(CACGTG, TATA)","(CACGCG, CATGTG)","(CACGCG, CACGAG)","(CACGCG, CATGCG)","(CACGCG, CACATG)","(CACGTG, CATGTG)","(CACGTG, CATGCG)","(CACGTG, CACGAG)","(CACGTG, CACATG)","(CATGCG, TATA)","(CACGAG, TATA)","(CATGTG, TATA)","(CACATG, TATA)","(CATGCG, CATGTG)","(CATGCG, CACGAG)","(CATGTG, CACGAG)","(CATGCG, CACATG)","(CACGAG, CACATG)","(CATGTG, CACATG)" ),
  MAE = c( 0.31184845037727343, 0.3202135481558392, 0.3150816629186174,0.3180145222377496,0.3197534673465196,0.3197836700631467,0.31980040465362736,0.3202584880647318,0.3202650095039427,0.39234306663671487,0.39813583430109695,0.3994306826710691,0.40115287361471935,0.4013111257726628,0.40135896209398736,0.4017460579195072,0.40220619987564826,0.4025545263233498,0.4025618672129832,0.4032905407249042,0.40796488997062724,0.40844149158913357,0.40855632779490497,0.40933350796938756,0.4114900720787698,0.411636893604258,0.4118183071869297,0.4123388646484469,0.4126084385850232,0.41307839772639715 )
)

# Define the baseline MAE
baseline_mae <- 0.4144

df_pairs = df_pairs %>% head(15) %>% rbind(df_pairs %>% tail(5))

# Plot the MAE for pairs of features
plot = ggplot(df_pairs, aes(x = reorder(Feature, -MAE), y = MAE, fill = MAE < baseline_mae)) +
  geom_bar(stat = "identity") +
  geom_hline(yintercept = baseline_mae, linetype = "dashed", color = "red", linewidth = 1) +
  coord_flip() +  # Flip coordinates for better readability
  labs(#title = "Pairwise MAE for log(MYC Coverage) of Linear Regression Models by Features (top 15 and bottom 5)",
       x = "Feature Pair",
       y = "Mean Absolute Error (MAE)",
       fill = "Better than Baseline") +
  scale_fill_manual(values = c("TRUE" = alpha("deepskyblue3", 0.7), "FALSE" = "gray")) +
  theme_minimal() +
  guides(fill = "none") +
  theme(plot.title = element_text(hjust = 0.5)) +
theme(panel.grid = element_blank(), axis.line = element_line(color = "black"), axis.ticks = element_line(color = "black", size = 1),)
plot
ggsave("./box_mea_coverage_2_feature.pdf", plot, width = 9, height = 6)
